<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * This is the model class for table "{{comments}}".
 *
 * The followings are the available columns in table '{{comments}}':
 * @property integer $id
 * @property integer $parent_id
 * @property string $content_id
 * @property integer $user_id
 * @property string $moderator_email
 * @property string $firstname
 * @property string $lastname
 * @property string $email
 * @property string $subject
 * @property string $description
 * @property integer $notify_moderator
 * @property integer $notify_user
 * @property integer $status
 * @property string $createtime
 * @property string $language
 */

class Comment extends CActiveRecord
{

    /**
     * Values for $status field
     */
    const NOT_APPROVED = 0;
    const APPROVED = 1;
    const DELETED = -1;

    /**
     * @var string field for capcha validation
     */
    public $verifyCode;
    protected $requiredForAnonymous = null;

    /**
     * Returns the static model of the specified AR class.
     *
     * @param string $className active record class name
     *
     * @return array|CActiveRecord
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * Returns the name of the associated database table.
     * By default this method returns the class name as the table name.
     * You may override this method if the table is not named after this convention.
     *
     * @return string the table name
     */
    public function tableName()
    {
        return '{{comments}}';
    }
    /**
     * Set the value of the protected variable $requiredForAnonymous
     */
    public function setRequiredForAnonymous($requiredForAnonymous){

        $this->requiredForAnonymous = $requiredForAnonymous;
    }
    /**
     * Returns the array which include information about fields requirement
     *
     * @return array if field is require
     */
    public function getRequiredForAnonymous(){

        $initialValue = true;

        if(isset($this->requiredForAnonymous) && $this->requiredForAnonymous == false){
            $initialValue = false;
        }

        $Required = array(
            'email' => $initialValue,
            'firstname' => $initialValue,
            'lastname' => $initialValue,
        );

        if(isset($this->requiredForAnonymous) && $this->requiredForAnonymous){

            $requiredFields = explode(',', $this->requiredForAnonymous);
            function trim_value(&$value){
                $value = trim($value);
            }
            array_walk($requiredFields, 'trim_value');
            foreach($Required as $fieldName=>&$isRequired){
                if(in_array($fieldName,$requiredFields)){
                    $isRequired = true;
                }else{
                    $isRequired = false;
                }
            }
        }
        return $Required;
    }

    /**
     * Returns the validation rules for attributes.
     *
     * @return array
     */
    public function rules()
    {
        $rules = array();

        $requiredForAnonymous = $this->getRequiredForAnonymous();

        foreach($requiredForAnonymous as $fieldName => $isRequire){
            if($isRequire){
                $rules[] = array( $fieldName, 'required', 'on' => 'createAnonymous');
            }
        }

        $rules = CMap::mergeArray($rules, array(
            array('content_id, subject, description, language', 'required'),
            array('email', 'required', 'except' => 'createAnonymous'),
            array('parent_id, user_id, status', 'numerical', 'integerOnly' => true),
            array('notify_moderator, notify_user', 'boolean'),
            array('content_id, moderator_email, firstname, lastname, email, subject, createtime, language', 'length', 'max' => 255),
            array('email, moderator_email', 'email'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, content_id, email, subject, description, parent_id, user_id, notify, status, moderator_email, firstname, lastname, createtime', 'safe', 'on' => 'search'),
            array('firstname, lastname, description, email, subject','filter', 'filter'=>array($obj=new CHtmlPurifier(),'purify')),
        ));
        if (Yii::app()->getController()) {
            $rules[] = array('verifyCode', 'captcha', 'on' => 'createAnonymous');
            $rules[] = array('verifyCode', 'captcha', 'on' => 'create');
        }
        return $rules;
    }

    /**
     * Return list of related object declarations
     *
     * @return array
     */
    public function relations()
    {
        return array(
            'childs' => array(self::HAS_MANY, 'Comment', 'parent_id', 'alias' => 'comments_childs'),
            'parent' => array(self::BELONGS_TO, 'Comment', 'parent_id')
        );
    }

    /**
     * Returns the default named scope that should be implicitly applied to all queries for this model.
     *
     * @return array
     */
    public function defaultScope()
    {
        return array(
            'condition' => 'status != ' . self::DELETED
        );
    }

    /**
     * Returns the declaration of named scopes.
     *
     * @return array
     */
    public function scopes()
    {
        return array(
            'approved' => array(
                'condition' => 'status = ' . self::APPROVED
            ),
            'isParent' => array(
                'condition' => 't.parent_id is NULL'
            ),
            'isChild' => array(
                'condition' => 't.parent_id is NOT NULL'
            )
        );
    }

    /**
     * Delete comment
     *
     * @param bool $completely if true delete from database
     *
     * @return bool
     */
    public function delete($completely = false)
    {
        if ($completely) {
            return parent::delete();
        } else {
            $this->status = self::DELETED;
            return $this->update('status');
        }
    }

    /**
     * Get comment hash
     *
     * @return string comment hash for delete via email
     */
    public function hash()
    {
        $str = $this->id . $this->parent_id . $this->subject . $this->description . $this->email . Yii::app()->getModule('comments')->hashSalt;
        return md5($str);
    }

    /**
     * Get attribute labels
     *
     * @return array
     */
    public function attributeLabels()
    {
        return array(
            'content_id' => CommentsModule::t('Content id'),
            'email' => CommentsModule::t('Email'),
            'subject' => CommentsModule::t('Subject'),
            'description' => CommentsModule::t('Description'),
            'parent_id' => CommentsModule::t('Parent id'),
            'user_id' => CommentsModule::t('User id'),
            'notify_user' => CommentsModule::t('Notify me on new comments'),
            'status' => CommentsModule::t('Status'),
            'moderator_email' => CommentsModule::t('Moderator email'),
            'firstname' => CommentsModule::t('First name'),
            'lastname' => CommentsModule::t('Last name'),
            'verifyCode' => CommentsModule::t('Verify Code'),
        );
    }

    /**
     * Comment status in readable format
     *
     * @return string
     */
    public function getStatusText()
    {
        $label = '';
        switch ($this->status) {
        case self::DELETED:
            $label = CommentsModule::t('Deleted');
            break;
        case self::NOT_APPROVED:
            $label = CommentsModule::t('Not approved');
            break;
        case self::APPROVED:
            $label = CommentsModule::t('Approved');
            break;
        }
        return $label;
    }

    /**
     * Search
     *
     * @return CActiveDataProvider
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('parent_id', $this->parent_id);
        $criteria->compare('content_id', $this->content_id, true);
        $criteria->compare('user_id', $this->user_id);
        $criteria->compare('moderator_email', $this->moderator_email, true);
        $criteria->compare('firstname', $this->firstname, true);
        $criteria->compare('lastname', $this->lastname, true);
        $criteria->compare('email', $this->email, true);
        $criteria->compare('subject', $this->subject, true);
        $criteria->compare('description', $this->description, true);
        $criteria->compare('notify_moderator', $this->notify_moderator);
        $criteria->compare('notify_user', $this->notify_user);
        $criteria->compare('status', $this->status);
        $criteria->compare('createtime', $this->createtime, true);

        return new CActiveDataProvider($this, array('criteria' => $criteria,));
    }

}