<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * Controller which recieve all requests to Content Repository
 *
 * All request for pages which should be rendered(html, php) handled by actionDynamic()
 * All other requests, for static content (img, doc, pdf, etc.) handled by actionStatic()
 * Css and js files also handled by actionStatic() if they are not wrapped
 * in Yii::app()->clientScript->registerCssFile() or Yii::app()->clientScript->registerScriptFile().
 * If they are wrapped then they will compressed and stored in /assets folder.
 *
 * To handle request to specific node from content repository add these lines into routers.php
 * 'rules' => array(
'<path:nodename\/.+\.(php|html)>' => 'contentRepository/dynamic',
'<path:nodename\/.+>' => 'contentRepository/static',
),
 * nodename - name of node(for exaple - gportal)
 *
 */
class RendererController extends BaseController
{
    /**
     * Default action
     *
     * @return void
     */
    function actionIndex()
    {
        $this->redirect(Yii::app()->createUrl(Yii::app()->getModule('user')->homePageUrl));
    }

    /**
     * Action which render all static content: js, css, doc, pdf files etc.
     *
     * @throws CHttpException
     * @throws Exception
     *
     * @return void
     */
    function actionStatic()
    {
        if (Yii::app()->request->getParam('path',false)) {
            $path = '/' . Yii::app()->request->getParam('path','');

            $content = $this->_getContentSource()->getContent($path);
            if ($content) {
                if ($content->hasAccess(Yii::app()->user)) {
                    $fileContent = file_get_contents($content->getFile());
                    array_map(
                        function($header)
                        {
                            header($header);
                        },
                        array_merge(
                            HeadersHelper::forFile($path, $fileContent), HeadersHelper::cache(3600)
                        )
                    );
                    echo $fileContent;
                    die;
                } else {
                    $this->_noAccess($content);
                }
            } else {
                if (YII_DEBUG) {
                    throw new Exception('Path not exists: ' . $this->_getContentSource()->contentSource->contentFile($path));
                } else {
                    throw new CHttpException(404);
                }
            }
        }
    }

    /**
     * Action which render all dynamic content: php, html files
     *
     * @throws CHttpException
     * @throws Exception
     *
     * @return void
     */
    function actionDynamic()
    {
        if (Yii::app()->request->getParam('path',false)) {
            $path = '/' . Yii::app()->request->getParam('path','');

            $content = $this->_getContentSource()->getContent($path);
            if ($content) {


                if ($content->hasAccess(Yii::app()->user)) {
                    $content = $this->renderFile($content->getFile(), null, true);
                    echo $this->processOutput($content);
                } else {
                    $this->_noAccess($content);
                }
            } else {
                if (YII_DEBUG) {
                    throw new Exception('Path not exists: ' . $this->_getContentSource()->contentSource->contentFile($path));
                } else {
                    throw new CHttpException(404);
                }
            }
        }
    }

    /**
     * Handle folder start page. In case user make request to folder like /Content.Node/service/
     *
     * @return void
     * @author Me
     **/
    public function actionStartPage()
    {
        if($this->module->getContentSource() instanceof FileSystemContentSource) {
            throw new CHttpException(404);
        }

        $folder = Yii::app()->request->getParam('folder', '').'/';
        $startPage = $this->module->getContentSource()->getStartPage($folder, substr(Yii::app()->locale->id, 0, 2));

        if($startPage === false) {
            $startPage = '/' . Yii::app()->request->getParam('path','') . $folder . $this->module->startPageFallback;
        }

        if($this->module->startPageDynamic) {
            $_GET['path'] = substr($startPage,1);
            $this->actionDynamic();
        } else {
            $this->redirect($startPage);
        }
    }
    /**
     * Sets corresponding messages and performs redirect if user don't have access to requested content
     *
     * @param string $path content path
     *
     * @return void
     */
    private function _noAccess($content)
    {
        if (Yii::app()->user->isGuest) {
            $message = UserModule::t('Please login to access required content.');
        } else {
            $message = UserModule::t("You don't have enough rights to access this content. You should have such permissions: {permissions}", array('{permissions}'=> implode(', ', $content->getPersonalisationAttributes())));
        }

        Yii::app()->user->setFlash(
            Yii::app()->getModule('user')->userLoginWidgetFlashError,
            $message
        );
        Yii::app()->user->setReturnUrl($content->getPath());
        $this->redirect(Yii::app()->getModule('user')->loginUrl);
    }

    public function processOutput($output){
        $processed = parent::processOutput($output);
        $headPosition = strpos($processed, '<head>');
        $is_head = false;
        preg_match("/<head>(?P<head_content>.*)<\/head>/s", $processed, $is_head);
        if(!empty($is_head)){
            $is_head = trim($is_head['head_content']);
            $is_head = strlen($is_head) ? true: false;
        }else{
            $is_head = false;
        }
        if($headPosition && $is_head){
            $processed = substr_replace($processed, AppHelper::footprint('<!-- generated by Gentics Portal.Node -->'), $headPosition, 0);
        }
        return $processed;
    }

    /**
     * Register css file in page
     *
     * @param string $file      filename
     * @param null   $timestamp last update timestamp of this file
     * @param bool   $combine   if combine and compress this file
     * @param string $media     media that the CSS code should be applied to. If empty, it means all media types.
     *
     * @return void
     */
    public function getCss($file, $timestamp = null, $combine = true, $media = '')
    {
        Yii::app()->clientScript->registerCssFile($file, $media, $timestamp, $combine, true, true);
    }

    /**
     * Register js file in page
     *
     * @param string $file      filename
     * @param null   $timestamp last update timestamp of this file
     * @param bool   $combine   if combine and compress this file
     *
     * @return void
     */
    public function getJs($file, $timestamp = null, $combine = true)
    {
        Yii::app()->clientScript->registerScriptFile($file, CClientScript::POS_HEAD, $timestamp, $combine, true, true);
    }

    /**
     * Register general javascript library which is used by page and widgets and which should be of the same version in many palces.
     * For example jQuery library
     *
     * @param string $file filename
     *
     * @return void
     */
    public function getCoreJs($file)
    {
        Yii::app()->clientScript->registerCoreScript($file, true);
    }

    /**
     * Get current content source for Static or Dynamic content renderer
     *
     * @return ContentSourceModule
     */
    private function _getContentSource()
    {
        return Yii::app()->getModule('contentSource');
    }
}
