<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 */
class FriendsController extends BaseController
{
    public function filters()
    {
        return array(
            'accessControl', // perform access control for CRUD operations
        );
    }

    public function accessRules()
    {
        return array(
            array('allow',
                'users' => array('@'),
            ),
            array('deny', // deny all users
                'users' => array('?'),
            ),
        );
    }

    /**
     * Initialise friendship between two users
     *
     * @param string $return_url return url
     *
     * @throws CHttpException
     */
    public function actionAdd($return_url)
    {
        if (!isset($_GET['key'], $_GET['user_id']) || FriendsModule::encrypting($_GET['user_id']) != $_GET['key']) {
            throw new CHttpException(400);
        }

        $friendship = Friendship::model()->findByPk(array('user1_id' => Yii::app()->user->id, 'user2_id' => $_GET['user_id']));
        if ($friendship) {
            $message = FriendsModule::t('You have already sent request.');
            if ($friendship->status == Friendship::STATUS_NOT_APPROVED) {
                $message .= FriendsModule::t('Not approved yet.');
            } elseif ($friendship->status == Friendship::STATUS_APPROVED) {
                $message .= FriendsModule::t('Approved yet.');
            } elseif ($friendship->status == Friendship::STATUS_CANCELED) {
                $message .= FriendsModule::t('Canceled by user.');
            }
            Yii::app()->user->setFlash('friends-error', $message);
            $this->redirect($return_url);
        }

        $friendship = new Friendship();
        $friendship->user1_id = Yii::app()->user->id;
        $friendship->user2_id = $_GET['user_id'];
        $friendship->status = Friendship::STATUS_NOT_APPROVED;
        $friendship->save();

        Yii::app()->user->setFlash('friends-success', FriendsModule::t("Your friend request was sent"));
        $title = FriendsModule::t('Friendship request');
        $notification = new Notification(
            $title,
            $this->renderMail('/mail_templates/add', $title, array('friendship' => $friendship)),
            array(new EmailRecipient($friendship->friend(Yii::app()->user->id)->email, $this->module->notificationsEmail))
        );
        Yii::app()->notificationManager->notifyAbout($notification);

        $this->redirect($return_url);

    }

    /**
     * Approve friendship between two users
     *
     * @param string $return_url return url
     *
     * @throws CHttpException
     */
    public function actionApprove($return_url = '')
    {
        if (!isset($_GET['key'], $_GET['user_id']) || FriendsModule::encrypting($_GET['user_id']) != $_GET['key']) {
            throw new CHttpException(400);
        }

        $friendship = Friendship::model()->findByPk(array('user1_id' => $_GET['user_id'], 'user2_id' => Yii::app()->user->id));
        if (!$friendship) {
            Yii::app()->user->setFlash('friends-error', FriendsModule::t("Bad request"));
            $this->redirect(Yii::app()->getModule('user')->friendListUrl);
        }
        if ($friendship->status != Friendship::STATUS_APPROVED) {
            $friendship->status = Friendship::STATUS_APPROVED;
            $friendship->save();
            Yii::app()->user->setFlash('friends-success', FriendsModule::t("Friend request was approved"));

            $title = FriendsModule::t('Friendship approved');
            $notification = new Notification(
                $title,
                $this->renderMail('/mail_templates/approve', $title, array('friendship' => $friendship)),
                array(new EmailRecipient($friendship->friend(Yii::app()->user->id)->email, $this->module->notificationsEmail))
            );
            Yii::app()->notificationManager->notifyAbout($notification);
        } else {
            Yii::app()->user->setFlash('friends-error', FriendsModule::t("Friend request already approved"));
        }

        if ($return_url) {
            $this->redirect($return_url);
        } else {
            $this->redirect(Yii::app()->getModule('user')->friendListUrl);
        }
    }

    /**
     * Cancel friendship between two users
     *
     * @param string $return_url return url
     *
     * @throws CHttpException
     */
    public function actionCancel($return_url = '')
    {
        if (!isset($_GET['key'], $_GET['user_id']) || FriendsModule::encrypting($_GET['user_id']) != $_GET['key']) {
            throw new CHttpException(400);
        }

        $friendship = Friendship::model()->findByPk(array('user1_id' => $_GET['user_id'], 'user2_id' => Yii::app()->user->id));
        if(!isset($friendship)){
            $friendship = Friendship::model()->findByPk(array('user2_id' => $_GET['user_id'], 'user1_id' => Yii::app()->user->id));
        }
        if ($friendship->status != Friendship::STATUS_CANCELED) {
            $friendship->status = Friendship::STATUS_CANCELED;
            $friendship->save();
            Yii::app()->user->setFlash('friends-success', FriendsModule::t("Friend request was canceled"));

            $title = FriendsModule::t('Friendship canceled');
            $notification = new Notification(
                $title,
                $this->renderMail('/mail_templates/cancel', $title, array('friendship' => $friendship)),
                array(new EmailRecipient($friendship->friend(Yii::app()->user->id)->email, $this->module->notificationsEmail))
            );
            Yii::app()->notificationManager->notifyAbout($notification);
        } else {
            Yii::app()->user->setFlash('friends-error', FriendsModule::t("Friend request already canceled"));
        }

        if ($return_url) {
            $this->redirect($return_url);
        } else {
            $this->redirect(Yii::app()->getModule('user')->friendListUrl);
        }
    }

}
