<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * Comment controller class file.
 *
 * @author Vitalii Kovalchuk <vitaly.kovalchuk@oberig.com>
 */

/**
 * Comment controller class
 *
 * @author Vitalii Kovalchuk <vitaly.kovalchuk@oberig.com>
 *
 */
class LikeController extends Controller
{
    /**
     * default action used to like or unlike content
     *
     * @return bool
     */
    public function actionIndex()
    {
        $contentId = Yii::app()->request->getPost('contentId', 0);

        if (Yii::app()->user->isGuest || $contentId<=0) {
            return false;
        }

        $model = Like::model()->findByAttributes(array('content_id'=>$contentId, 'user_id'=>Yii::app()->user->id));

        if ($model) {

            $model->delete();

            $result['caption'] = '<span>' . LikeModule::t('Like') . '</span>';
        } else {
            /*  user have not liked this content so make him like it  */

            $model = new Like();

            $model->content_id = $contentId;
            $model->user_id = Yii::app()->user->id;
            $model->createdate = date('Y-m-d H:i:s');
            $model->save();

            $result['caption'] = '<span>' . LikeModule::t('Unlike') . '</span>';
        }

        /*  formatting result array */
        $result = array(
            'contentId' => $model->content_id,
            'likesQty' => $model->getLikesQty(),
            'caption' => $result['caption'],
        );

        /*  set likes qty limitations */
        $model->lastLikesQty = Yii::app()->getModule('like')->lastLikesQty;
        $model->topLikesQty = Yii::app()->getModule('like')->topLikesQty;

        /*  get top and last likes depending on config set above */
        $likes = $model->getLikes();

        $result['topLikes'] = array();
        if ($model->topLikesQty > 0 && count($likes) > 0) {
            for ($i = 0; $i < $model->topLikesQty && $i < count($likes); $i++) {
                if ($likes[$i]->profile->user_id==Yii::app()->user->id) {
                    $result['topLikes'][] = LikeModule::t('You');
                } else {
                    if (trim($likes[$i]->profile->firstname)!='' || trim($likes[$i]->profile->lastname)!='') {
                        $result['topLikes'][] = $likes[$i]->profile->firstname.' '.$likes[$i]->profile->lastname;
                    } else {
                        $result['topLikes'][] = LikeModule::t('Noname');
                    }
                }
            }

            if (count($likes) > $model->topLikesQty) {
                $result['andOthers'] = LikeModule::t('and').' '.($result['likesQty'] - $model->topLikesQty).' '.LikeModule::t('others like this');
            }
        }

        $result['lastLikes'] = array();
        if ($model->lastLikesQty > 0 && (count($likes) - $model->topLikesQty) > 0) {
            for ($i = $model->topLikesQty; $i < ($model->topLikesQty + $model->lastLikesQty) && $i < count($likes); $i++) {
                if ($likes[$i]->profile->user_id==Yii::app()->user->id) {
                    $result['lastLikes'][] = LikeModule::t('You');
                } else {
                    if (trim($likes[$i]->profile->firstname)!='' || trim($likes[$i]->profile->lastname)!='') {
                        $result['lastLikes'][] = $likes[$i]->profile->firstname.' '.$likes[$i]->profile->lastname;
                    } else {
                        $result['lastLikes'][] = LikeModule::t('Noname');
                    }
                }
            }

            if ($result['likesQty'] > count($likes)) {
                $result['lastLikes'][] = LikeModule::t('And others...');
            }
        }

        echo json_encode($result);
    }

    /**
     * Intermidiate action. Used for saving $return_url in session to return back after log in.
     *
     * @param string $return_url - return url
     *
     * @return void
     */
    public function actionLogin($return_url)
    {
        Yii::app()->user->setReturnUrl($return_url);
        $this->redirect(Yii::app()->getModule('like')->loginUrl);
    }
}
