<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * Navigation module class file.
 */
class NavigationModule extends CWebModule
{
    /**
     * @var int the number of seconds in which the cached value will expire. 0 means never expire.
     */
    public $cacheTime = 60;

    /**
     * @var int the number of seconds in which the cached value will expire. 0 means never expire. Used for caching updatetimestamps
     */
    public $timestampCacheTime = 20;

    /**
     * @var string path to module assets
     */
    private $_assetsUrl;

    /**
     * @var array that contains list of URLs that should not be shown in navigation trees
     */
    public $excludeURLs = array();

    /**
     * Import dependent classes
     *
     * @return void
     */
    public function init()
    {
        // import the module-level components
        $this->setImport(
            array(
                'navigation.components.*',
            )
        );
    }

    /**
     * Translates a message to the specified language.
     *
     * @param string $str    message
     * @param array  $params params
     * @param string $dic    dictionary
     *
     * @return string
     */
    public static function t($str = '', $params = array(), $dic = 'Navigation')
    {
        return Yii::t("NavigationModule." . $dic, $str, $params);
    }


    /**
     * Returns path to assets for current module
     *
     * @return string
     */
    public function getAssetsUrl()
    {
        if (!$this->_assetsUrl) {
            $this->_assetsUrl = Yii::app()->assetManager->publish(Yii::getPathOfAlias('navigation.views.asset'), true);
        }
        return $this->_assetsUrl;
    }
}
