<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 */
class ManageController extends Controller
{

    /**
     * Returns filers array
     *
     * @return array
     */
    public function filters()
    {
        return array(
            'accessControl'
        );
    }

    /**
     * returns filter rules
     *
     * @return array
     */
    public function accessRules()
    {
        return array(
            array(
                'allow',
                'roles' => array('Admin')
            ),
            array(
                'deny',
                'users' => array('*')
            )
        );
    }

    /**
     * saves personalisation attribute
     *
     * @throws CHttpException
     *
     * @return void
     */
    public function actionSaveAttribute()
    {
        if (!isset($_POST['parent_id'], $_POST['id'], $_POST['name'], $_POST['title'])) {
            throw new CHttpException(400);
        }

        if (strpos($_POST['id'], 'tmp_') === 0) {
            $attribute = new PersonalisationAttribute();
            if ($_POST['parent_id'] !== 'root') {
                $attribute->childOf(PersonalisationAttribute::model()->findByPk($_POST['parent_id']));
            }
        } else {
            $attribute = PersonalisationAttribute::model()->findByPk($_POST['id']);
            if (!$attribute) {
                throw new CHttpException(400);
            }
        }
        $attribute->name = $_POST['name'];
        $attribute->title = !empty($_POST['title']) ? $_POST['title'] : $_POST['name'];
        if ($attribute->save()) {
            echo CJSON::encode(array('id' => $attribute->id, 'parent_id' => $attribute->parent_id, 'name' => $attribute->name, 'title' => $attribute->title));
            Yii::app()->end();
        } else {
            $errorsString = array();
            foreach ($attribute->getErrors() as $field => $errors) {
                $errorsString[] = $field . ': ' . implode(', ', $errors);
            }
            echo CJSON::encode(array('error' => implode('; ', $errorsString)));
            Yii::app()->end();
        }
    }

    /**
     * Deletes personalisation attribute
     *
     * @throws CHttpException
     *
     * @return void
     */
    public function actionDeleteAttribute()
    {
        if (isset($_POST['id'])) {
            $pa = PersonalisationAttribute::model()->findByPk($_POST['id']);
            if ($pa->delete()) {
                echo CJSON::encode(array());
            } else {
                echo CJSON::encode(array('error' => PersonalisationModule::t('Can\'t delete attribute')));
            }
            Yii::app()->end();
        } else {
            throw new CHttpException(400);
        }
    }

    /**
     * Updates user personalisation attribute
     *
     * @return void
     */
    public function actionUpdateUserAttribute()
    {
        if (isset($_POST['user_id']) && isset($_POST['id']) && isset($_POST['state']) && User::model()->findByPk($_POST['user_id'])) {
            if ($_POST['state'] == 1) {
                if (PersonalisationAttribute::model()->findByPk($_POST['id'])) {
                    $upa = new UserPersonalisationAttribute();
                    $upa->user_id = $_POST['user_id'];
                    $upa->personalisation_attribute_id = $_POST['id'];
                    $upa->save();
                }
            } else {
                UserPersonalisationAttribute::model()->deleteAllByAttributes(array('user_id' => $_POST['user_id'], 'personalisation_attribute_id' => $_POST['id']));
            }
        }
    }

}
