<?php

/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * RememberModule
 * This module allows user to remember pages he was visited and then share them using Facebook, mail or printing
 *
 * Interaction with module performs with two widgets and one link creation function
 * Widgets:
 * - LastRemembered - displays last N remembered pages
 * - ShareRemembered - allows deleting, sorting, search and share remembered links
 *
 * RememberModule::createLink() function creates special link for page. When user clicks on it then page with parametrs remembered in database. 
 *
**/
class RememberModule extends CWebModule
{
        /**
         * This key used for making digital signature, which not allows user to change data
         *
         * @var string
         **/
        public $signSalt = 'sign-salt';

        /**
         * Email used as "Send From:" in sharing by email 
         *
         * @var string
         **/
        public $shareByMailEmail = 'remember@example.com';

        /**
         * Subject used in sharing by email 
         *
         * @var string
         **/
        public $shareByMailSubject = 'Remember subject';
      
        /**
         * Facebook application id used for sharing using fb API
         *
         * @var string
         **/
        public $facebookApplicationId;
        
        
        /**
         * Prevents abuse of the PDF-generator by only rendering allowed URLs
         *
         * @var string
         **/
        public $allowedURL = "";
        
       /**
         * Name of the generated PDF-File for download or mailing
         *
         * @var string
         **/
        public $pdfname = "";
        
        
        /**
         * Where to write the generated PDF-File temporarly
         *
         * @var string
         **/
        public $tmpFolder;

        public function init()
        {
            $this->setImport(array(
                'remember.models.*'
            )); 
        }

        /**
         * Get current user collection id
         *
         * @return string
         **/
        public function getUserCollectionId()
        {
            return Yii::app()->user->isGuest ? Yii::app()->session->getSessionId() : Yii::app()->user->id;
        }

        /**
         * Translates a message to the specified language.
         *
         * @param string $str    message
         * @param array  $params params
         * @param string $dic    dictionary
         *
         * @return string
         */
        public static function t($str = '', $params = array(), $dic = 'core')
        {
            return Yii::t("RememberModule." . $dic, $str, $params);
        }

        /**
         * Make digital signature for string using md5
         *
         * @return string
         **/
        public function sign($string)
        {
            return md5($string . $this->signSalt);
        }
}
