<?php

/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * ManageController used for managing operations with RememberedPages like view, add, delete, share
 *
**/
class ManageController extends BaseController
{
    public $layout = false;

    /**
     * Remembering page into database
     * This action performs validations to prevent unautorized access
     *
     * @return void
     **/
    public function actionAdd($url, $title, $page_id, $additional, $key, $back_to_referer)
    {
        $data = array(
            'url'=> $_GET['url'],
            'title'=> $_GET['title'],
            'page_id'=> $_GET['page_id'],
            'additional' => $_GET['additional'],
            'back_to_referer' => (boolean) $_GET['back_to_referer'],
        );

        if($this->module->sign(serialize($data)) !== $key) {
            throw new CHttpException(400, 'Invalid key');
        }

        $rememberedPage = new RememberedPage();
        $rememberedPage->collection_id = Yii::app()->getModule('remember')->getUserCollectionId();

        $rememberedPage->url = $url;
        $rememberedPage->title = $title;
        $rememberedPage->page_id = $page_id;
        $rememberedPage->additional = unserialize($additional);

        if(!$rememberedPage->save()){

            throw new CHttpException(400, 'Internal error');
        }
        $this->redirect($back_to_referer === 'true' ? Yii::app()->request->getUrlReferrer() : $url);
    }

    /**
     * Action for sharing links by mail
     *
     * @var string
     **/
    public function actionShareByMail()
    {
        $mailForm = new ShareMailForm();
        if(isset($_POST['ShareMailForm'])){
            $mailForm->attributes = $_POST['ShareMailForm'];
        }

        if($mailForm->validate()) {

            $mail = new PHPMailer(true);
            $mail->SetFrom($this->module->shareByMailEmail);
            $mail->AddAddress($mailForm->email);
            $mail->Subject = $this->module->shareByMailSubject;
            
	        $subject = $this->module->shareByMailSubject;

            $mailurls = array();
            $mailurls_msg = $mailForm->links;
            $mailurls_ = explode('<a href="http',$mailForm->links);
            foreach($mailurls_ as $mailurls__){
                $end = explode('"',$mailurls__);
                if (trim($end[0]) != "" && strstr($end[0],$this->module->allowedURL) && !in_array(trim("http".$end[0]), $mailurls)){
                    $mailurls[] = trim("http".$end[0]);
                }
            }
            
            if (sizeof($mailurls) > 0){
            	$mail->AddStringAttachment($this->actionLoadPdf($mailurls), $this->module->pdfname);
            }
            
            $msg = $this->renderPartial('/mail_templates/share_by_email', array('links'=>$mailurls_msg, 'description' => $mailForm->description), true);
            $mail->MsgHTML(utf8_decode($msg)); 
  	    $mail->Send();
        }

        echo CActiveForm::validate($mailForm);
        Yii::app()->end();
    }
 
    /**
     * Action for downloading PDFs
     *
     * @var string
     **/
    public function actionDownloadPdf()
    {
            $mailurls = array();
            $mailurls_ = explode(' ',Yii::app()->request->getParam("links",""));
            foreach($mailurls_ as $mailurls__){
                if (trim($mailurls__) != "" && strstr($mailurls__,$this->module->allowedURL) && !in_array(trim($mailurls__), $mailurls)){
                    $mailurls[] = trim($mailurls__);
                }
            }
            if (sizeof($mailurls) > 0){
              header("Content-Type: application/pdf");
              header("Content-disposition: attachment; filename=".$this->module->pdfname);
              header("Pragma: no-cache");
              echo $this->actionLoadPdf($mailurls);
              exit;

            } else {
                echo RememberModule::t("Error");
            }
    }

    public function actionLoadPdf($mailurls)
    {
        $filename = $this->module->tmpFolder.md5(date(DATE_RFC822).join("",$mailurls)).".pdf";
        $statement = "wkhtmltopdf-amd64 -n --zoom 1 --page-width 1280px --footer-center \[page\] -T 14mm -B 14mm -L 14mm -R 14mm --disable-external-links --disable-internal-links ".join(" ",$mailurls)." ".$filename;#--disable-smart-shrinking
        exec($statement);
        $out = file_get_contents($filename);
        unlink($filename);
        return $out;
    }

    /**
     * Deleting single remembered page
     *
     * @return void
     **/
    public function actionDeletePage()
    {
        $id = Yii::app()->request->getQuery('id', '');
        $isAjax = Yii::app()->request->isAjaxRequest;
        $collectionId = Yii::app()->getModule('remember')->getUserCollectionId();

        $ids = explode(",",$id);
        foreach($ids as $id){
            $rememberedPage = RememberedPage::model()->findByPk($id);

            if($rememberedPage && $rememberedPage->collection_id == $collectionId){
                $rememberedPage->delete();
            }else{
                throw new CHttpException(400);
            }
        }
        if(!$isAjax){
            if(isset($_SERVER['HTTP_REFERER'])){
                $this->redirect($_SERVER['HTTP_REFERER']);
            }
        }else{
            echo json_encode(array('status'=>'success'));
        }
    }
}
