<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 */

class SearchModule extends CWebModule
{
    /**
     * @var int the number of seconds in which the cached value will expire. 0 means never expire.
     */
    public $cacheTime = 360;

    /**
     * @var string default landing page(page with SearchResultWidget)
     */
    public $defaultLandingPage;

    /**
     * @arrays array landing pages for every language(pages with SearchResultWidget in different languages)
     */
    public $landingPages;

    /**
     * @var string personalisation delimiter. Used to split personalisation string after search request
     */
    public $personalisationDelimiter;

    /**
     * @var string personalisation delimiter. Used to split personalisation string after search request
     */
    public $perPage;

    /**
     * @var array configuration for mimetypes
     */
    public $mimetype;

    /**
     * @var array configuration for where to search
     */
    public $whereToSearch;

    /**
     * @var array configuration for search type
     */
    public $searchType;

    /**
     * @var string string that always will be added to search requests
     */
    public $staticString = '';

    /**
     * @var array configuration for url filtering
     */
    public $urlLimiter;

    /**
     * gets repository API
     *
     * @return void
     */
    public function getApi()
    {
        return Yii::app()->repositoryApi;
    }

    /**
     * gets value for current sep up of search landing page
     *
     * @param string $lang - defines required language
     *
     * @return string
     */
    public static function getLandingPage($lang)
    {
        $dbSetting = Yii::app()->getModule('settings')->get('landingPage_'.$lang);
        if (!empty($dbSetting)) {
            /*  check if we have landing page for current language set up in DB */
            $landingPage = $dbSetting;
        } else {
            $dbSetting = Yii::app()->getModule('settings')->get('defaultLandingPage');
            if (!empty($dbSetting)) {
                /*  check if we have default landing page for set up in DB */
                $landingPage = $dbSetting;
            } else if (isset(Yii::app()->getModule('search')->landingPages[$lang]) && Yii::app()->getModule('search')->landingPages[$lang] != '') {
                /*  check if we have landing page for current language sep up in config  */
                $landingPage = Yii::app()->getModule('search')->landingPages[$lang];
            } else if (isset(Yii::app()->getModule('search')->defaultLandingPage) && Yii::app()->getModule('search')->defaultLandingPage != '') {
                /*  check if we have default landing page sep up in config  */
                $landingPage = Yii::app()->getModule('search')->defaultLandingPage;
            } else {
                /*  take current page url as landing page */
                $landingPage = '';
            }
        }

        return $landingPage;
    }

    /**
     * Import dependent classes
     *
     * @return void
     */
    public function init()
    {
        // import the module-level components
        $this->setImport(
            array(
                'search.components.*',
            )
        );
    }

    /**
     * Translates a message to the specified language.
     *
     * @param string $str    message
     * @param array  $params params
     * @param string $dic    dictionary
     *
     * @return string
     */
    public static function t($str = '', $params = array(), $dic = 'search')
    {
        return Yii::t("SearchModule." . $dic, $str, $params);
    }
}
