<?php
/**
 *
 */
class SettingsModule extends CWebModule
{
    /**
     * @var array array of fields which will be available
     * for editing via web interface and stored in DB.
     * All other settings will be skipped
     */
    public $fields;

    public $layoutForBackend = '//layouts/gportal';
    /**
     * Model initial method
     *
     * @return void
     */
    public function init()
    {
        parent::init();
        $this->setImport(
            array(
                'settings.models.*'
            )
        );
    }

    /**
     * Method for getting setting from DB
     *
     * @param string $name setting name
     *
     * @return mixed
     */
    public function get($name)
    {
        if (!in_array($name, $this->fields)) {
            return false;
        }
        return Settings::instance()->get($name);
    }

    /**
     * Method for saving setting into DB
     *
     * @param string $name  setting name
     * @param mixed  $value setting value
     *
     * @return bool if success
     */
    public function set($name, $value)
    {
        if (!in_array($name, $this->fields)) {
            return false;
        }
        Settings::instance()->set($name, $value);
        return true;
    }

    /**
     * Translates a message to the specified language.
     *
     * @param string $str    message
     * @param array  $params params
     * @param string $dic    dictionary
     *
     * @return string
     */
    public static function t($str = '', $params = array(), $dic = 'core')
    {
        return Yii::t("SettingsModule." . $dic, $str, $params);
    }

}
