<?php

/**
 * This is the model class for table "settings".
 *
 * The followings are the available columns in table 'settings':
 * @property integer $id
 * @property string $settings
 */
class Settings extends CActiveRecord
{
    private static $_instance;

    /**
     * Returns the static model of the specified AR class.
     *
     * @param string $className active record class name.
     *
     * @return Settings the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * Returns model table name
     *
     * @return string the associated database table name
     */
    public function tableName()
    {
        return '{{settings}}';
    }

    /**
     * Sets some rules
     *
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('settings', 'required'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, settings', 'safe', 'on' => 'search'),
        );
    }

    /**
     * Allows model relations definition
     *
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
        );
    }

    /**
     * Singleton method
     *
     * @return Settings.
     */
    public static function instance()
    {
        if (!self::$_instance) {
            $settings = Settings::model()->find();
            if (is_null($settings)) {
                $settings = new Settings();
                $settings->settings = array();
                $settings->save();
            }
            self::$_instance = $settings;
        }
        return self::$_instance;
    }

    /**
     * resets model instance
     *
     * @return void
     */
    public static function reload()
    {
        self::$_instance = null;
        return self::instance();
    }

    /**
     * Returns setting by given name
     *
     * @param string name settings parameter name
     *
     * @return mixed
     */
    public function get($name)
    {
        return isset($this->settings[$name]) ? $this->settings[$name] : false;
    }

    /**
     * Settings setter
     *
     * @param string $name  name
     * @param mixed  $value value
     *
     * @return void
     */
    public function set($name, $value)
    {
        $this->settings = array_merge($this->settings, array($name => $value));
        $this->save();
    }

    /**
     * Deletes parameter by name
     *
     * @param string $name name
     *
     * @return void
     */
    public function unsetValue($name)
    {
        $s = $this->settings;
        unset($s[$name]);
        $this->settings = $s;
        $this->save();
    }

    /**
     * Performes some action before model is saved
     *
     * @return mixed
     */
    protected function beforeSave()
    {
        $this->settings = serialize($this->settings);
        return parent::beforeSave();
    }

    /**
     * Performes some action after model is saved
     *
     * @return mixed
     */
    protected function afterSave()
    {
        $this->settings = unserialize($this->settings);
        parent::afterSave();
    }

    /**
     * Performes some action before model is found
     *
     * @return mixed
     */
    protected function afterFind()
    {
        $this->settings = unserialize($this->settings);
        parent::afterFind();
    }

    /**
     * Returns customized attribute labels (name=>label)
     *
     * @return array
     */
    public function attributeLabels()
    {
        return array(
            'id' => 'ID',
            'settings' => 'Settings',
        );
    }

}