<?php

/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * This is the model class for table "{{order}}".
 *
 * The followings are the available columns in table '{{order}}':
 * @property string $id
 * @property integer $ordered
 * @property string $user_id
 * @property string $shipping_info
 * @property string $payment_info
 */
class Order extends CActiveRecord
{
    private $_userId;

    const ORDERED = 1;
    const PROCESS = 0;

    public $verifyCode;

	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return Order the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}
	
	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{order}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('ordered', 'numerical', 'integerOnly'=>true),
            array('shipping_info, payment_info', 'length', 'max'=>1024),
			array('user_id', 'length', 'max'=>10),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id, ordered, user_id, tmp_user_id, shipping_info, payment_info', 'safe', 'on'=>'search'),
            array('verifyCode','captcha','allowEmpty'=>!Yii::app()->user->isGuest || !CCaptcha::checkRequirements() || !Yii::app()->getModule('shoppingcart')->captchaEnabled, 'captchaAction' => '/shoppingcart/shoppingcart/captcha'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
            'items'    => array(self::HAS_MANY,   'Item',    'order_id'),
		);
	}
    /**
     * @return array named scopes.
     */
    public function scopes()
    {
        return array(
            'ordered'=>array(
                'condition'=>'ordered='.self::ORDERED,
            ),
            'process'=>array(
                'condition'=>'ordered='.self::PROCESS,
            ),
        );
    }

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id'      => ShoppingcartModule::t('ID'),
			'ordered' => ShoppingcartModule::t('Ordered'),
			'user_id' => ShoppingcartModule::t('User'),
            'shipping_info' => ShoppingcartModule::t('Shipping Info'),
            'payment_info' => ShoppingcartModule::t('Payment Info'),
            'verifyCode' => ShoppingcartModule::t('Verify Code'),
		);
	}
    /*
     * The method returns the model of actual order or its id
     * @param integer $id_only  bool value that determines what will be returned
     * @return object | integer
     */
    public static function getOrder($id_only = false){

        $user_id = self::getUser(true);

        $model = self::model()
                ->process()->find(
                    array('condition'=>'user_id=:user_id','params'=> array(':user_id' =>$user_id))
                );

        if(!isset($model)){
            $model = new Order;
            $model->user_id  = $user_id;
            $model->save(false);
        }

        return $id_only? $model->id: $model;
    }
    /*
     * The method returns the model od id of user who is owner of actual order
     * @param integer $id_only  bool value that determines what will be returned
     * @return object | integer
     */
    public static function getUser($id_only = false)
    {
        if(!isset($user_id) && isset(Yii::app()->user->id)){
            $user = TmpUser::model()->with('order')->find('t.parent_user_id=:parent_user_id AND order.ordered=:process',
                array(':parent_user_id'=>Yii::app()->user->id,':process'=>Order::PROCESS));
            if(isset($user)){
                Yii::app()->user->setState('user_id', $user->id);
            }
        }

        $user_id = Yii::app()->user->getState('user_id');
        if(!isset($user_id)){
            $user_id = (string)Yii::app()->request->cookies['user_id'];
            Yii::app()->user->setState('user_id', $user_id);
        }

        if(isset($user_id) && !isset($user)) {
            $user = TmpUser::model()->findByPk($user_id);
        }

        if(!isset($user)){
             $user = new TmpUser;
             if(isset(Yii::app()->user->id)){
                 $user->parent_user_id = Yii::app()->user->id;
             }
             $user->save(false);
             Yii::app()->user->setState('user_id', $user->id);
             if (!headers_sent()){
                 $cookie = new CHttpCookie('user_id', $user->id);
                 $cookie->expire = time()+60 * Yii::app()->getModule('shoppingcart')->max_lifetime;
                 $cookie->domain=Yii::app()->getModule('shoppingcart')->cookie_domain;
                 Yii::app()->request->cookies['user_id'] = $cookie;
             }
        }

        if(isset(Yii::app()->user->id) && !isset($user->parent_user_id)){
            $user->parent_user_id = Yii::app()->user->id;
            $user->save(false);
        }

        return $id_only? $user->id: $user;
    }


	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id',$this->id,true);
		$criteria->compare('ordered',$this->ordered);
		$criteria->compare('user_id',$this->user_id,true);
        $criteria->compare('shipping_info',$this->shipping_info,true);
        $criteria->compare('payment_info',$this->order_info,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}
