<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * This is the model class for table "{{tmp_user}}".
 *
 * The followings are the available columns in table '{{tmp_user}}':
 * @property int    $id
 * @property string $salutation
 * @property string $firstname
 * @property string $lastname
 * @property string $company
 * @property string $birthday
 * @property string $street
 * @property string $zip_code
 * @property string $city
 * @property string $country
 * @property string $telephone
 * @property string $email
 * @property string $memberNo
 */
class TmpUser extends CActiveRecord
{
    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return TmpUser the static model class
     */
    public static function model($className=__CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return '{{tmp_user}}';
    }

    protected function afterFind()
    {
        $format = Yii::app()->locale->getDateFormat();
        $oldDate = $this->birthday;
        $this->birthday = Yii::app()->dateFormatter->format($format, $oldDate);
        parent::afterFind();
    }

    protected function beforeSave()
    {
        if(parent::beforeSave()) {

            $dateFormat = Yii::app()->locale->getDateFormat();
            $dateFormat = ($dateFormat == 'MMM d, y')?'MMM d, yyyy':$dateFormat;

            $this->birthday = date('Y-m-d',
                CDateTimeParser::parse($this->birthday,
                    $dateFormat));
            return true;
        } else {
            return false;
        }
    }

    /**
    protected function beforeSave()
    {
        if(parent::beforeSave())
        {
            // Format dates based on the locale
            foreach($this->metadata->tableSchema->columns as $columnName => $column)
            {
                if ($column->dbType == 'date')
                {
                    $this->$columnName = date('Y-m-d',
                        CDateTimeParser::parse($this->$columnName,
                            Yii::app()->locale->getDateFormat('short')));
                }
                elseif ($column->dbType == 'datetime')
                {
                    $this->$columnName = date('Y-m-d H:i:s',
                        CDateTimeParser::parse($this->$columnName,
                            Yii::app()->locale->getDateTimeFormat('short')));
                }
            }
            return true;
        }
        else
            return false;
    }
    protected function afterFind()
    {
        // Format dates based on the locale
        foreach($this->metadata->tableSchema->columns as $columnName => $column)
        {
            if (!strlen($this->$columnName)) continue;

            if ($column->dbType == 'date')
            {
                $this->$columnName = Yii::app()->dateFormatter->formatDateTime(
                    CDateTimeParser::parse(
                        $this->$columnName,
                        'yyyy-MM-dd'
                    ),
                    'short',null
                );
            }
            elseif ($column->dbType == 'datetime' || $column->dbType == 'timestamp')
            {
                $this->$columnName = Yii::app()->dateFormatter->formatDateTime(
                    CDateTimeParser::parse(
                        $this->$columnName,
                        'yyyy-MM-dd hh:mm:ss'
                    ),
                    'short','short'
                );
            }
        }
        return parent::afterFind();
    }
    **/
    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        $dateFormat = Yii::app()->locale->getDateFormat();
        $dateFormat = ($dateFormat == 'MMM d, y')?'MMM d, yyyy':$dateFormat;

        return array(
            array('salutation, firstname, lastname, street, zip_code, city, country, email', 'required'),
            array('salutation, firstname, lastname, company, street, zip_code, city, country, telephone, email', 'length', 'max'=>255),
            array('email','email'),
            array('birthday','date','format' => $dateFormat), //'dd.MM.yyyy'
            array('birthday', 'safe'),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('id, salutation, firstname, lastname, company, birthday, street, zip_code, city, country, telephone, email', 'safe', 'on'=>'search'),
            array('salutation, firstname, lastname, street, zip_code, city, country, email, birthday, telephone, company','filter', 'filter'=>array($obj=new CHtmlPurifier(),'purify')),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'order' => array(self::HAS_ONE, 'Order', 'user_id'),
        );
    }

    /*
     * The method return registered user model that connect with order
     * @return object
     */
    public function getExistUser()
    {
        return Profile::model()->findByPk($this->parent_user_id);
    }

    /**
     * @return array customized attribute labels (name=>label)
     */

    public function attributeLabels()
    {
        return array(
            'id' => ShoppingcartModule::t('ID'),
            'salutation' => ShoppingcartModule::t('Salutation'),
            'firstname' => ShoppingcartModule::t('First Name'),
            'lastname' => ShoppingcartModule::t('Last Name'),
            'company' => ShoppingcartModule::t('Company'),
            'birthday' => ShoppingcartModule::t('Date Of Birth'),
            'street' => ShoppingcartModule::t('Street'),
            'zip_code' => ShoppingcartModule::t('Zip Code'),
            'city' => ShoppingcartModule::t('City'),
            'country' => ShoppingcartModule::t('Country'),
            'telephone' => ShoppingcartModule::t('Telephone'),
            'email' => ShoppingcartModule::t('Email'),
        );
    }
    /*
     * The method implement fields from registered profile
     * @return object
     */
    public function implementFromSession(){

        if(isset($this->parent_user_id)){
            $user = Profile::model()->findByPk($this->parent_user_id);
            if(isset($user)){
                foreach($this->attributes as $fieldName => $value){
                    if(isset($user->$fieldName) && empty($this->$fieldName)){
                        $this->$fieldName = $user->$fieldName;
                    }
                }
            }
        }

        return $this;
    }
    /*
     * The method unset fields that exists in registered profile
     * @return object
     */
    public function unsetExistFields(){

        if(isset($this->parent_user_id)){
            $user = Profile::model()->findByPk($this->parent_user_id);
            if(isset($user)){
                foreach($this->attributes as $fieldName => $value){
                    if(isset($user->$fieldName) && isset($this->$fieldName)
                        && $user->$fieldName==$this->$fieldName){
                        unset($this->$fieldName);
                    }
                }
            }
        }

        return $this;
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria=new CDbCriteria;

        $criteria->compare('id',$this->id,true);
        $criteria->compare('salutation',$this->salutation,true);
        $criteria->compare('first_name',$this->first_name,true);
        $criteria->compare('last_name',$this->last_name,true);
        $criteria->compare('company',$this->company,true);
        $criteria->compare('date_of_birth',$this->date_of_birth,true);
        $criteria->compare('street',$this->street,true);
        $criteria->compare('zip_code',$this->zip_code,true);
        $criteria->compare('city',$this->city,true);
		$criteria->compare('svnr',$this->svnr,true);
		$criteria->compare('memberNo',$this->memberNo,true);
        $criteria->compare('country',$this->country,true);
        $criteria->compare('telephone',$this->telephone,true);
        $criteria->compare('email',$this->email,true);

        return new CActiveDataProvider($this, array(
            'criteria'=>$criteria,
        ));
    }

}
