<?php

/**
 * Checks if user has ability to perform login
 **/
class BadLoginAttemptsFilter extends CFilter
{
    /**
     * Controller var for storing flag described if attempts remains
     *
     * @public string
     **/
    public $blockedVar = 'attemptsEnded';

    /**
     * Controller var for storing flag showing remained blocking time
     *
     * @public string
     **/
    public $timeRemainsVar = 'timeRemains';

    /**
     * Number of login attempts
     *
     * @public int
     **/
    public $attemptsCount = 3;
    
    /**
     * Time for blicking account
     *
     * @public string
     **/
    public $blockTime = 360;

	/**
	 * Performs the pre-action filtering.
	 * @param CFilterChain $filterChain the filter chain that the filter is on.
	 * @return boolean whether the filtering process should continue and the action
	 * should be executed.
	 */
	protected function preFilter($filterChain)
	{
        if(Yii::app()->request->isPostRequest && Yii::app()->user->isGuest){
            $record = LoginAttempt::model()->findByAttributes(array('ip' => Yii::app()->request->userHostAddress));
            if($record){
                //time eleapsed
                $timeRemains = $this->blockTime - (time() - strtotime($record->updated));
                $filterChain->controller->{$this->timeRemainsVar} = $timeRemains;
                if( $timeRemains <= 0) {
                    $record->attempts = 0;
                    $record->save();
                } elseif($record->attempts >= $this->attemptsCount){
                    //block
                    $filterChain->controller->{$this->blockedVar} = true;
                }
            }
        }

		return true;
	}

	/**
	 * If user is guest after login attepmt then it means that password was invalid.
     * Increment counter in db by ip address
     *
	 * @param CFilterChain $filterChain the filter chain that the filter is on.
	 */
	protected function postFilter($filterChain)
	{
        //if access not blocked
        if(Yii::app()->request->isPostRequest && Yii::app()->user->isGuest && $filterChain->controller->{$this->blockedVar} !== true){
            $ip = Yii::app()->request->userHostAddress;
            $record = LoginAttempt::model()->findByAttributes(array('ip' => $ip));
            if($record){
                if($record->attempts < $this->attemptsCount){
                    $record->attempts += 1;    
                    $record->save();
                }
            } else {
                $record = new LoginAttempt();
                $record->ip = $ip;
                $record->save();
            }
        }
	}
}
