<?php

class AdminController extends Controller
{
    public $defaultAction = 'admin';

    private $_model;

    /**
     * Allows to set some filters
     *
     * @return array action filters
     */
    public function filters()
    {
        return CMap::mergeArray(
            parent::filters(),
            array(
                'accessControl', // perform access control for CRUD operations
            )
        );
    }

    /**
     * Specifies the access control rules.
     * This method is used by the 'accessControl' filter.
     *
     * @return array access control rules
     */
    public function accessRules()
    {
        return array(
            array('allow', // allow authenticated users to access all actions
                'roles'=>array('Admin'),
            ),
            array('deny', // deny all users
                'users' => array('*'),
            ),
        );
    }

    /**
     * Manages all models.
     *
     * @return void
     */
    public function actionAdmin()
    {
        $model = new User('search');
        $model->status = null;
        $model->is_bulk = null;
        if (isset($_GET['User'])) {
            $model->attributes = $_GET['User'];
        }
        $this->render('index', array('model' => $model,));
    }


    /**
     * Displays a particular model.
     *
     * @return void
     */
    public function actionView()
    {
        $model = $this->loadModel();

        $attributes = array(
            'id',
            'username',
        );

        array_push($attributes,
            'password',
            'email',
            'activkey',
            array(
                'name' => 'createtime',
                'value' => $model->createtime,
            ),
            array(
                'name' => 'lastvisit',
                'value' => (($model->lastvisit) ? $model->lastvisit : UserModule::t("Not visited")),
            ),
            array(
                'name' => 'status',
                'value' => User::itemAlias("UserStatus", $model->status),
            )
        );

        $profileFields = ProfileField::model()->forOwner()->sort()->findAll();

        if ($profileFields) {
            foreach ($profileFields as $field) {
                $value = null;
                $varname = $field->varname;
                if(in_array($varname, array("send_me_notifications", "find_me_in_phone_book")) ){
                    $value = ($model->profile->$varname == 1)? true : false;
                }else{
                    $value = ($field->widgetView($model->profile)) ? $field->widgetView($model->profile) : (($field->range) ? Profile::range($field->range, $model->profile->getAttribute($field->varname)) : $model->profile->getAttribute($field->varname));
                }
                array_push($attributes, array(
                    'label' => UserModule::t($field->title),
                    'name' => $field->varname,
                    'value' => $value,
                ));
                unset($value);
            }
        }

        foreach ($attributes as $i => &$attribute) {
            if(!is_null($attribute)&&(in_array($attribute, array("password","activkey")))){
                unset($attributes[$i]);
            }
            elseif (is_null($attribute['value'])) {
                $attribute['value'] = '';
            }
        }

        $this->render(
            'view', array(
                'model' => $model,
                'attributes' => $attributes,
            )
        );
    }

    /**
     * Creates a new model.
     * If creation is successful, the browser will be redirected to the 'view' page.
     *
     * @return void
     */
    public function actionCreate()
    {
        $model = new User;
        $profile = new Profile;
        if (isset($_POST['User'])) {
            $model->attributes = $_POST['User'];
            $model->activkey = Yii::app()->controller->module->encrypting(microtime() . $model->password);
            $model->createtime = date('Y-m-d H:i:s');
            $model->lastvisit = date('Y-m-d H:i:s');
            $profile->attributes = $_POST['Profile'];
            $profile->user_id = 0;
            if ($model->validate() && $profile->validate()) {
                $model->password = Yii::app()->controller->module->encrypting($model->password);
                if ($model->save()) {
                    $profile->user_id = $model->id;
                    $profile->save();
                }
                $this->redirect(array('view', 'id' => $model->id));
            } else {
                $profile->validate();
            }
        }

        $this->render(
            'create', array(
                'model' => $model,
                'profile' => $profile,
            )
        );
    }

    /**
     * Updates a particular model.
     * If update is successful, the browser will be redirected to the 'view' page.
     *
     * @return void
     */
    public function actionUpdate()
    {
        $model = $this->loadModel();
        $profile = $model->profile;
        if (isset($_POST['User'])) {
            $model->attributes = $_POST['User'];
            $profile->attributes = $_POST['Profile'];

            if ($model->validate() && $profile->validate()) {
                $old_password = User::model()->notsafe()->findByPk($model->id);
                if ($old_password->password != $model->password) {
                    $model->password = Yii::app()->controller->module->encrypting($model->password);
                    $model->activkey = Yii::app()->controller->module->encrypting(microtime() . $model->password);
                }
                $model->save();
                $profile->save();
                $this->redirect(array('view', 'id' => $model->id));
            } else {
                $profile->validate();
            }
        }

        $this->render(
            'update', array(
                'model' => $model,
                'profile' => $profile,
            )
        );
    }


    /**
     * Deletes a particular model.
     * If deletion is successful, the browser will be redirected to the 'index' page.
     *
     * @throws CHttpException
     * @return void
     */
    public function actionDelete()
    {
        if (Yii::app()->request->isPostRequest) {
            // we only allow deletion via POST request
            $model = $this->loadModel();
            $profile = Profile::model()->findByPk($model->id);

            if ($account = Account::model()->findByAttributes(array('user_id'=>$model->id))) {
                $account->delete();
            }

            $profile->delete();
            $model->delete();
            // if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
            if (!isset($_POST['ajax'])) {
                $this->redirect(array('/user/admin'));
            }
        } else {
            throw new CHttpException(400, 'Invalid request. Please do not repeat this request again.');
        }
    }

    /**
     * Renders ManagePersonalisation view
     *
     * @return void
     */
    public function actionManagePersonalisation()
    {
        $this->render('managePersonalisation');
    }


    /**
     * Returns the data model based on the primary key given in the GET variable.
     * If the data model is not found, an HTTP exception will be raised.
     *
     * @throws CHttpException
     * @return void
     */
    public function loadModel()
    {
        if ($this->_model === null) {
            if (isset($_GET['id'])) {
                $this->_model = RegistrationForm::model()->notsafe()->findbyPk($_GET['id']);
            }
            if ($this->_model===null) {
                throw new CHttpException(404, 'The requested page does not exist.');
            }
        }
        return $this->_model;
    }

}
