<?php

class LoginController extends Controller
{
    public $defaultAction = 'login';

    /**
     * Variable which is used by BadLoginAttemptsFilter to indicate that attepts are ended
     *
     * @public string
     **/
    public $attemptsEnded = false;

    /**
     * Variable which is used by BadLoginAttemptsFilter to show remaiend for blocking login
     *
     * @public string
     **/
    public $timeRemains;

    public function filters(){
        return array(
            array(
                'BadLoginAttemptsFilter + standard',
                'attemptsCount' => $this->module->loginBadAttemps,
                'blockTime' => $this->module->loginBlockTime,
            )
        );    
    }

    public function actionStandard()
    {
        $loginForm = new UserLogin();
        if(!$this->attemptsEnded){
            $loginForm = new UserLogin();
            $loginForm->attributes = @$_POST['UserLogin'];
            if ($loginForm->validate()) {
                if ($loginForm->service == 'standard' && array_key_exists('standard', Yii::app()->eauth->services)) {
                    $userIdentity = new UserIdentity($loginForm->authField, $loginForm->password);
                    if($userIdentity->authenticate() && !isset($_POST['ajax'])) {
                        Yii::app()->user->setState('UserLogin', null);
                        $returnUrl = Yii::app()->user->getReturnUrl();
                        Yii::app()->user->login($userIdentity, $this->module->loggedInDuration * intval($loginForm->rememberMe));
                        if($returnUrl != '/'){
                            $this->redirect($returnUrl);
                        }
                        Yii::app()->user->setFlash(Yii::app()->getModule('user')->userLoginWidgetFlashSuccess, UserModule::t('You have been successfully logged in.'));
                    } else {
                        $loginForm->applyErrors($userIdentity);
                    }
                    if (isset($_REQUEST['ajax'])) {
                        // ajax validator
                        echo $loginForm->getAjaxErrors();
                        Yii::app()->end();
                    } else {
                        //if no ajax validation save model data to session
                        Yii::app()->user->setState('UserLogin', array('attributes' => $loginForm->attributes, 'errors' => $loginForm->getErrors()));
                    }
                } else { 
                    throw new CHttpException(400, 'Wrong service');
                }
            } elseif (isset($_POST['ajax'])){
                echo $loginForm->getAjaxErrors();
                Yii::app()->end();
            } else {
                Yii::app()->user->setState('UserLogin', array('attributes' => $loginForm->attributes, 'errors' => $loginForm->getErrors()));
            }
        } else {
             Yii::app()->user->setFlash(
             $this->module->userLoginWidgetFlashError, UserModule::t('Please wait {s} seconds before next login.', array('{s}' => $this->timeRemains)));
        }

        if (isset($_POST['return_url'])) {
            $this->redirect($_POST['return_url'], false);
        } else{
            $this->render('/user/login', array('model' => $loginForm));
        }
    }

    public function actionTpa()
    {
        $loginForm = new UserLogin();
        $loginForm->attributes = @$_GET['UserLogin'];
        if (isset($_GET['ajax'])){
            echo $loginForm->getAjaxErrors();
            Yii::app()->end();
        }
        if ($loginForm->validate()) {
            if ($loginForm->service != 'standard' && array_key_exists($loginForm->service, Yii::app()->eauth->services)) {
                if(isset($_GET['ajax'])) {
                    throw new CHttpException(400, 'Wrong request');
                }
                $serviceIdentity = Yii::app()->eauth->getIdentity($loginForm->service);
                $serviceIdentity->redirectUrl = Yii::app()->user->returnUrl;
                $serviceIdentity->cancelUrl = $this->createAbsoluteUrl('user/login');
                if ($serviceIdentity->authenticate()) {
                    $serviceIdentity->getAttributes();
                    $this->onTPAAuthorizationSuccess($serviceIdentity);
                    $userIdentity = new SUserIdentity($serviceIdentity);
                    if($userIdentity->authenticate()) {
                        Yii::app()->user->setState('UserLogin', null);
                        Yii::app()->user->login($userIdentity, $this->module->loggedInDuration * intval($loginForm->rememberMe));
                    } else {
                        $loginForm->applyErrors($userIdentity);
                    }
                } else {
                    Yii::app()->user->setFlash('error', $serviceIdentity->getError());
                }
            } else { 
                throw new CHttpException(400, 'Wrong service');
            }
        } else {
            Yii::app()->user->setState('UserLogin', array('attributes' => $loginForm->attributes, 'errors' => $loginForm->getErrors()));
        }

        if (isset($_GET['return_url'])) {
            $this->redirect($_GET['return_url']);
        } else
            $this->render('/user/login', array('model' => $loginForm));
    }


    private function lastViset()
    {
        $lastVisit = User::model()->notsafe()->findByPk(Yii::app()->user->id);
        $lastVisit->lastvisit = time();
        $lastVisit->save();
    }

    public function onLogin($userIdentity)
    {
        $message = "User: {$userIdentity->username} logged in. Return URL: " . Yii::app()->user->returnUrl . ". \$_REQUEST['return_url']: " . @$_REQUEST['return_url'];
        $notification = new Notification('Login', $message);
        Yii::app()->notificationManager->notifyAbout($notification);
    }


    public function onTPAAuthorizationSuccess($serviceIdentity)
    {
        $message = "Account {$serviceIdentity->getEmail()} from TPA: {$serviceIdentity->serviceName} successfuly authorized\n";
        $notification = new Notification('TPA', $message);
        Yii::app()->notificationManager->notifyAbout($notification);
    }

}
