<?php

class User extends CActiveRecord
{
    const STATUS_NOACTIVE = 0;
    const STATUS_ACTIVE = 1;
    const STATUS_BANED = -1;

    /*
     * Field shows user should to be imported
     */
    protected $isExists = null;

    public $justSaved = false;
    /**
     * @var string for backend search
     */
    public $firstname;

    /**
     * @var string for backend search
     */
    public $lastname;

    /**
     * The followings are the available columns in table 'users':
     * @var integer $id
     * @var string $username
     * @var string $password
     * @var string $email
     * @var string $activkey
     * @var integer $createtime
     * @var integer $lastvisit
     * @var integer $superuser
     * @var integer $status
     */

    /**
     * Returns the static model of the specified AR class.
     * @return CActiveRecord the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return Yii::app()->getModule('user')->tableUsers;
    }

//    public function behaviors()
//    {
////        return array('datetimeI18NBehavior' => array('class' => 'DateTimeI18NBehavior'));
//    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.

        if(Yii::app()->getModule('user')->isAdmin()){
            return array(
                #array('username, password, email', 'required'),
                array('username', 'length', 'max' => 20, 'min' => 3, 'message' => UserModule::t("Incorrect username (length between 3 and 20 characters).")),
                array('password', 'length', 'max' => 128, 'min' => 4, 'message' => UserModule::t("Incorrect password (minimal length 4 symbols).")),
                array('email', 'email', 'message' => UserModule::t("Email invalid.") ),
                array('username', 'unique', 'message' => UserModule::t("This user's name already exists."), 'except'=>'nameIsNotUniq'),
                array('email', 'unique', 'message' => UserModule::t("This user's email address already exists.")),
                array('username', 'match', 'pattern' => '/^[A-Za-z0-9_]+$/u', 'message' => UserModule::t("Incorrect symbols (A-z0-9).")),
                array('status', 'in', 'range' => array(self::STATUS_NOACTIVE, self::STATUS_ACTIVE, self::STATUS_BANED), 'message' => UserModule::t("Incorrect status.")),
                array('username, email, status', 'required'),
                array('status', 'numerical', 'integerOnly' => true),
                //array('createtime', 'default', 'value' => date('Y-m-d H:i:s')), move to db
                //array('lastvisit', 'default', 'value' => NULL),
                array('createtime, lastvisit', 'type', 'type' => 'datetime', 'datetimeFormat' => 'yyyy-MM-dd hh:mm:ss', 'message' => UserModule::t("Date invalid.") ),
                array('id, username, password, email, activkey, createtime, lastvisit, status, is_bulk, firstname, lastname', 'safe', 'on' => 'search'),
            );
        }else{

            if(Yii::app()->user->id == $this->id){
                return array(
                    array('email', 'required'),
                    array('email', 'email'),
                    array('email', 'unique', 'message' => UserModule::t("This user's email address already exists.")),
                    array('status', 'numerical', 'integerOnly' => true),
                    //array('username', 'unique', 'message' => UserModule::t("This user's name already exists.")),
                    //array('username', 'match', 'pattern' => '/^[A-Za-z0-9_]+$/u', 'message' => UserModule::t("Incorrect symbols (A-z0-9).")),
                    array('username,email, createtime, lastvisit, status', 'safe', 'on' => 'search'),
                );
            }else{
                return array();
            }
        }
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        $relations = array(
            'profile' => array(self::HAS_ONE, 'Profile', 'user_id'),
        );
        if (isset(Yii::app()->getModule('user')->relations)) $relations = array_merge($relations, Yii::app()->getModule('user')->relations);
        return $relations;
    }

//    public function beforeSave()
//    {
//        if ($this->isNewRecord) {
//            if (empty($this->createtime)) {
//                $this->createtime = date('Y-m-d H:i:s');
//            }
//            $this->lastvisit = NULL;
//        }
//
//        return parent::beforeSave();
//    }

    /*
     * Method returns true if user with same email is already exists
     */
    public function isExists(){
        //if(!isset($this->isExists))
            $this->isExists = User::model()->count('email=:email',array(':email'=>$this->email))?true:false;
        return $this->isExists;
    }

    public static function create($account, $service)
    {
        $user = User::model()->findByAttributes(array('email' => $service->getEmail()));
        if (!$user) {
            $user = new User();
            $user->username = $service->getName();
            $user->attributes = array(
                //'username' => $service->getName(),    //for unknown reason this doesn't work
                'email' => $service->getEmail(),
                'password' => 'empty',
                'activkey' => 'empty',
                'status' => 1
            );

            if (!$user->save()) {
                throw new Exception(print_r($user->getErrors(), true));
            }

            $profile = new Profile;
            $profile->user_id = $user->id;

            if (isset($service->attributes['firstname'])) {
                $profile->firstname = $service->attributes['firstname'];
            }
            if (isset($service->attributes['lastname'])) {
                $profile->lastname = $service->attributes['lastname'];
            }
            if (isset($service->attributes['gender'])) {
                $profile->gender = $service->attributes['gender'];
            }

            if (!$profile->save(false)) {
                throw new Exception(print_r($profile->getErrors(), true));
            }
        }
        $account->user_id = $user->id;
        $account->save();

        return $user;
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'username' => UserModule::t("Username"),
            'password' => UserModule::t("Password"),
            'verifyPassword' => UserModule::t("Retype Password"),
            'email' => UserModule::t("E-mail"),
            'verifyCode' => UserModule::t("Verification Code"),
            'id' => UserModule::t("Id"),
            'activkey' => UserModule::t("activation key"),
            'createtime' => UserModule::t("Registration date"),
            'lastvisit' => UserModule::t("Last visit"),
            'status' => UserModule::t("Status"),
        );
    }

    public function scopes()
    {
        return array(
            'active' => array(
                'condition' => 'status=' . self::STATUS_ACTIVE,
            ),
            'notactvie' => array(
                'condition' => 'status=' . self::STATUS_NOACTIVE,
            ),
            'banned' => array(
                'condition' => 'status=' . self::STATUS_BANED,
            ),
            'superuser' => array(
            ),
            'notsafe' => array(
                'select' => 'id, username, password, email, activkey, createtime, lastvisit, status',
            ),
        );
    }

    public function defaultScope()
    {
        return array(
            'select' => 'id, username, email, createtime, lastvisit, status',
        );
    }

    public static function itemAlias($type, $code = NULL)
    {
        $_items = array(
            'UserStatus' => array(
                self::STATUS_NOACTIVE => UserModule::t('Not active'),
                self::STATUS_ACTIVE => UserModule::t('Active'),
                self::STATUS_BANED => UserModule::t('Banned'),
            ),
            'AdminStatus' => array(
                '0' => UserModule::t('No'),
                '1' => UserModule::t('Yes'),
            ),
        );
        if (isset($code))
            return isset($_items[$type][$code]) ? $_items[$type][$code] : false;
        else
            return isset($_items[$type]) ? $_items[$type] : false;
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('id', $this->id);
        $criteria->compare('username', $this->username, true);
        $criteria->compare('password', $this->password, true);
        $criteria->compare('email', $this->email, true);
        $criteria->compare('activkey', $this->activkey, true);
        $criteria->compare('createtime', $this->createtime, true);
        $criteria->compare('lastvisit', $this->lastvisit, true);
        $criteria->compare('status', $this->status);
        $criteria->compare('is_bulk', $this->is_bulk);

        $criteria->together = true;
        $criteria->with = array('profile');
        $criteria->compare('profile.firstname', $this->firstname, true);
        $criteria->compare('profile.lastname', $this->lastname, true);

        return new CActiveDataProvider($this, array(
            'criteria' => $criteria,
            'pagination' => array(
                'pageSize' => Yii::app()->controller->module->user_page_size,
            ),
        ));
    }
}