<?php
/**
 *
 */
class UserLoginWidget extends BaseUserWidget
{
    public $model;
    /**
     * @var string forgot password page url
     */
    public $recoveryUrl = '';

    /**
     * @var array contains list of available auth services
     */
    public $services = array();

    /**
     * @var array contains list of available auth service types
     */
    public $serviceTypes = array();

    public function init()
    {
        parent::init();
        Yii::app()->clientScript->registerScriptFile(Yii::app()->getModule('user')->getAssetsUrl() . '/js/userLoginServices.js');
    }

    /**
     * Load model and display login form
     *
     * @return void
     */
    public function run()
    {
        if (Yii::app()->user->isGuest) {
            if (empty(Yii::app()->eauth->services)) {
                return;
            }
            /*  loading auth services */
            $this->_loadServices();

            /*  loading auth service types */
            $this->_loadServiceTypes();

            $this->model or $this->model = new UserLogin();
            if (($userLoginData = Yii::app()->user->getState('UserLogin')) != null) {
                $this->model->attributes = $userLoginData['attributes'];
                foreach ($userLoginData['errors'] as $attribute => $errors) {
                    foreach ($errors as $e) {
                        $this->model->addError($attribute, $e);
                    }
                }
                Yii::app()->user->setState('UserLogin', null);
            }

            /*  if param recoveryUrl is not given - load recoveryUrl from config */
            if ($this->recoveryUrl == '') {
                $this->recoveryUrl = Yii::app()->getModule('user')->recoveryUrl;
            }

            $this->render('UserLoginWidget', array('model' => $this->model));
        } else {
            Yii::app()->user->setFlash(Yii::app()->getModule('user')->userLoginWidgetFlashSuccess, UserModule::t("You're logged in successfully"));
            $this->render('UserLoggedInWidget');
        }
    }

    public function isUseStandard()
    {
        return array_key_exists('standard', Yii::app()->eauth->services);
    }

    /**
     * Load available auth services
     *
     * @return void
     */
    private function _loadServices()
    {
        $services = Yii::app()->eauth->services;

        foreach ($services as $service=>$settings) {
            if (isset($settings['enabled']) && $settings['enabled']==false) {
                continue;
            }
            $this->services[$service] = UserModule::t(isset($settings['title']) ?  $settings['title'] : $service);
        }
    }

    /**
     * Load available auth services types
     *
     * @return void
     */
    private function _loadServiceTypes()
    {
        $services = Yii::app()->eauth->getServices();

        foreach ($services as $service=>$data) {
            $this->serviceTypes[$service] = $data->type;
        }
        $this->serviceTypes['standard'] = 'standard';
    }
}
?>