<?php

/**
 * Widget for pooling questions. Show question and available answers.
 *
 **/
class ResultsWidget extends CWidget
{
    /**
     * Unique question identification string
     *
     * @var string
     **/
    public $id;

    /**
     * If display statistics in percents
     *
     * @public bool
     **/
    public $inPercents = false;

    /**
     * Precision when display votes in percents
     *
     * @public string
     **/
    public $precision = 1;

    /**
     * If show results for user which havent vote(by checking session)
     *
     * @public boolean
     **/
    public $unvotedShow = true;
    /**
     * Precision when result displays above vote form
     *
     * @public string
     **/
    public $firstResult = false;

    public function run()
    {
        if(!$this->unvotedShow && !$this->getIsVoted() && !$this->firstResult) {
            return;
        }
        $question = Question::model()
            ->with(array('answers' => array('condition' => 'active = true', 'with' => array('userAnswersCount'))))
            ->findByPk($this->id);
        $answers = $question->answers;
        usort($answers, function($a, $b){ return $a->order - $b->order;});
        $statistics = array();
        $totalAnswers = 0;
        foreach($answers as $answ) {
            $totalAnswers += $answ->userAnswersCount;
            $statistics[] = array('title' => $answ->text, 'value' => (int)$answ->userAnswersCount);
        }
        if($this->inPercents) {
            foreach($statistics as &$row) {
                $row['value'] = round($totalAnswers === 0 ? 0 : ($row['value'] / $totalAnswers * 100), $this->precision);
            }
        }
        $this->render('ResultsWidget', array('question' => $question, 'statistics' => $statistics));
    }

    public function getIsVoted()
    {
        return Yii::app()->user->getState('vote-voted-'.$this->id) === true;
    }
}
