<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 *
 */
//define system paths
Yii::setPathOfAlias('site', '../../');
Yii::setPathOfAlias('ext', '../../common/extension');
Yii::setPathOfAlias('user', '../../common/modules/user');

return array(
    //frontend directory path
    'basePath' => dirname(__FILE__) . DIRECTORY_SEPARATOR . '..',
    //Name of the application. Will be shown in window title
    'name' => 'Gentics Portal.Node',
    //controller which is executed by default
    //when controller not specified in request url
    'defaultController' => 'contentSource/renderer',
    //the language that the application is written in. This mainly refers to
    //the language that the messages and view files are in. Defaults to 'en'
    'sourceLanguage' => 'en',
    //The language that the user is using and the application should be targeted to.
//    'language' => 'fr',
    //Raised right BEFORE the application processes the request.
    //Anonymous function set current application language from user session
    'onBeginRequest' => function () {
        Yii::app()->setLanguage(Yii::app()->user->getState('language', Yii::app()->language));
        Yii::app()->getModule('user');
        Yii::app()->getModule('comments');
        Yii::app()->getModule('rights');
        Yii::app()->getModule('personalisation');
        Yii::app()->getModule('history');
        Yii::app()->getModule('shoppingcart');
    },
    //Aliases for directory pathes
    'aliases' => array(
        'common' => 'site.common',
        'custom' => 'site.custom',
    ),
    //the IDs of the application components that should be preloaded. For better performance
    'preload' => array('log', 'session', 'notificator', 'errorHandler'),
    //String the charset currently used for the application. Defaults to 'UTF-8'.
    'charset' => 'UTF-8',
    //import folders with files, classes
    //Importing a class is like including the corresponding class file.
    //The main difference is that importing a class is much lighter because it only
    //includes the class file when the class is referenced the first time.
    //Importing a directory is equivalent to adding a directory into the PHP include path.
    //If multiple directories are imported, the directories imported later will take
    //precedence in class file searching (i.e., they are added to the front of the PHP include path).
    'import' => array(
        'common.models.*',
        'common.helpers.*',
        'common.components.*',
        'common.components.notification.*',
        'common.extensions.*',
        'common.components.content.*',
        'common.extensions.eauth.*',
        'common.extensions.eauth.services.*',
        'common.extensions.ExtendedClientScript.*',
        'application.components.*',
        'application.controllers.*',
        'zii.widgets.jui.CJuiWidget',
        'ext.*',
        'system.caching.*'
//        'application.modules.comments.*'
    ),
    'localeDataPath' => Yii::getPathOfAlias('site.common.i18n'),
    //The configuration of the currently installed modules (module ID => configuration).
    //detail config is in /modules folder
    'modules' => array(
        /**
        'gii' => array(
        'class' => 'system.gii.GiiModule',
        'password' => 'cru9',
        // If removed, Gii defaults to localhost only. Edit carefully to taste.
        'ipFilters' => array('127.0.0.1', '::1'),
        ),
         **/
        //Module for working with File System Content Renderer and Dynamic Content Renderer
        'contentSource' => array(
            //Module class location
            'class' => 'common.modules.contentSource.ContentSourceModule',
            //Current content renderer class
            //Allowed values:
            // - DynamicContentSource
            // - FileSystemContentSource
            'sourceClass' => 'DynamicContentSource',
            //Content repository settings
            'sourceSettings' => array(
                //Dynamic Content Renderer settings / RECOMMENDED
                'DynamicContentSource' => array(
                    //folder into which content will be cached
                    'cacheFolder' => '/var/www/vhosts/domain/portal/DCR',
                    //If use personalization for current content source
                    'usePersonalisation' => true,
                    //Array of fields which will be additionally request from Gentics Content Connector
                    //and used in personalisation checking algorithm
                    'personalisationFields' => array()
                ),
                //File System Content Renderer settings
                'FileSystemContentSource' => array(
                    //folder which contained File System Content Renderer content
                    'contentFolder' => '/var/www/vhosts/domain/portal/FSCR',
                    //If use personalization for current content source
                    'usePersonalisation' => true,
                    //Array of fields which will be additionally request from Gentics Content Connector
                    //and used in personalisation checking algorithm
                    'personalisationFields' => array()
                ),
            ),
            // in case you want folders to be used as start points
            'startPageDynamic' => true,
            // if we can't find a startpage in the Gentics Content Repository, the portal will try to use this filename
            'startPageFallback' => 'index.html',
            // name of attribute in Gentics Content Repository
            'localizedAttributeName' => 'startpageurl_',
            //the number of seconds in which the cached value will expire. 0 means never expire.
            //used for caching content personalisation attributes and modification time
            'cacheTime' => 60 * 2
        ),
        //personalized content module
        'personalizedContent' => array(
            //Component class
            'class' => 'common.modules.personalizedContent.PersonalizedContentModule',
            //  cache life time in seconds
            'cacheTime' => 60,
            //  exсludeURLs - URL's that should not be shown in navigation widgets like ''(empty) or '#' or '/', etc.
            'excludeURLs' => array('', '/', '#'),
            // GCC request params. Comma separated. Example: name,name_en.
            //Do not include personalisation attributes here, they will be added automatically.
            //updatetimestamp will also be added - because it is required
            'gccRequestParams' => 'languagecode,name,node_id,sortorder,permissions,navhidden,url',
            // how many entries per paging page
            'perPage' => 5,
        ),
        //yii-user module
        'user' => array(
            //Module class location
            'class' => 'common.modules.user.UserModule',
            //SendFrom email for password forgotten mails
            'passwordForgottenEmail' => 'portal.password@gentics.com',
            //encrypting method (php hash function)
            'hash' => 'md5',
            //send activation email
            'sendActivationMail' => true,
            //Subject of mail in activation mail. site_name - replaced by value 'name' in main.php
            'activationMailSubject' => 'You registered from {site_name}',
            //email which is displayed in 'Send from:" in activation mail
            'activationEmail' => 'portal.activation@gentics.com',
            //allow access for non-activated users
            'loginNotActiv' => false,
            'activeAfterRegister' => false,
            'loginBadAttemps' => 3,
            'loginBlockTime' => 300,
            'loginAjax'=> false,
            //automatically login from registration
            'autoLogin' => true,
            //
            'user_page_size' => 10,
            //
            'fields_page_size' => 10,

            //registration path
            'registrationUrl' => array(
                'en' => '/Content.Node/service/Registration.en.html',
                'de' => '/Content.Node/service/Registration.de.html',
            ),
            // link to the CMS page where UserRecoveryWidget is placed. Will be used in userLoginWidget as a href to corresponding page.
            'recoveryUrl' => array(
                'en' => '/Content.Node/service/Password-Recovery.en.html',
                'de' => '/Content.Node/service/Password-Recovery.de.html'
            ),
            //in pair with recoveryUrl
            'recoveryChangePasswordUrl' => array(
                'en' => '/Content.Node/service/Change_Password_Recovery.en.html',
                'de' => '/Content.Node/service/Change_Password_Recovery.de.html'
            ),
            //login form path
            'loginUrl' => array(
                'en' => '/Content.Node/service/Login.en.html',
                'de' => '/Content.Node/service/Login.de.html'
            ),
            //page after login
            'returnUrl' => array(
                'en' => '/Content.Node/service/Login.en.html',
                'de' => '/Content.Node/service/Login.de.html',
            ),
            //page where placed the profile editor
            'profileEditUrl' => array(
                'en' => '/Content.Node/service/UserProfileEditWidget.en.html',
                'de' => '/Content.Node/service/UserProfileEditWidget.de.html',
            ),
            //page after logout
            'returnLogoutUrl' => array(
                'en' => '/Content.Node/service/Login.en.html',
                'de' => '/Content.Node/service/Login.de.html',
            ),
            //if user has no permissions, go to this site
            'noPermissionsUrl' => array(
                'en' => '/site/noPermissions',
                'de' => '/site/noPermissions'
            ),
            // define startpages for portal
            'homePageUrl' => array(
                'en' => '/Content.Node/index.en.html',
                'de' => '/Content.Node/index.de.html'
            ),
            // only necessary if friends module is activated
            'friendListUrl' => array(
                'en' => '/Content.Node/intranet/corporatedirectory/friends/My_friends.en.html'
            ),
            //int number of seconds that the user can remain in logged-in status. Defaults to 0, meaning login till the user closes the browser.
            //If greater than 0, cookie-based login will be used.
            'loggedInDuration' => 60 * 60 * 24 * 30,
            //define which user field will be used in login process. 'email' or 'username'. If field != 'email' then username will be used
            'authField' => 'email',
            //define if username will be shown in register process
            'usernameRequired' => true,
            //define if username should be unique during registration
            'usernameUnique' => true,
            //minimum length of username field
            'usernameMin' => 4,
            //minimum length of password field
            'passwordMin' => 4,
            'relations' => array(
                'userPersonalisationAttribute' => array(CActiveRecord::HAS_MANY, 'UserPersonalisationAttribute', 'user_id'),
                'account' => array(CActiveRecord::HAS_ONE, 'Account', 'user_id'),
                'comments' => array(CActiveRecord::HAS_MANY, 'Comment', 'user_id')
            )
        ),
        //yii-rights module
        'rights' => array(
            //Module class location
            'class' => 'common.modules.rights.RightsModule',
            //the name of the username column in the user table. displayed in admin section
            'userNameColumn' => 'email',
            'appLayout' => 'application.views.layouts.gportal'
        ),
        //language module
        'language' => array(
            //Module class location
            'class' => 'common.modules.language.LanguageModule',
            //array of used languages
            'languages' => array(
                'en' => 'en',
                'de' => 'de'
            )
        ),
        //
        //'updates' => array(
        //    'class' => 'common.modules.updates.UpdatesModule',
        //    'currentVersion' => 0.1
        //),
        //bulk module - allows to fill database with lots of data
        'bulk' => array(
            //Module class location
            'class' => 'common.modules.bulk.BulkModule',
        ),
        //navigation module - allows to show navigation panels like topmenu, leftmenu, etc.
        'navigation' => array(
            //Module class location
            'class' => 'common.modules.navigation.NavigationModule',
            /*  cache life time in seconds */
            'cacheTime' => 60,
            /*  updatetimestamps cache life time in seconds */
            'timestampCacheTime' => 20,
            /*  exсlude URLs - URL's that should not ber shown in navigation widgets like ''(empty) or '#' or '/', etc. */
            'excludeURLs' => array('', '/', '#')
        ),
        //search module
        'search' => array(
            // class
            'class' => 'common.modules.search.SearchModule',
            //  cache life time in seconds
            'cacheTime' => 360,
            //  CMS page that contains SearchResultWidget
            'defaultLandingPage' => '/Content.Node/service/Search.en.html',
            // CMS landing pages for every language(pages with SearchResultWidget in different languages)
            'landingPages' => array(),
            // personalisation delimiter. Used to split personalisation string after search request
            'personalisationDelimiter' => ' ',
            //perPage defines how many found results should be displayed per page
            'perPage' => 5,
            'mimetype' => array(
                //show or not this field on advanced form
                'showOnAdvancedSearchForm' => true,
                //list of allowed mimetypes
                'options' => array(
                    'all' => 'All',
                    'html' => 'HTML pages',
                    'php' => 'PHP pages',
                    'pdf' => 'PDF documents',
                    'doc' => 'DOC documents',
                ),
                //default value
                'default' => 'all'
            ),
            'whereToSearch' => array(
                //show dropdown list on advanced search form to select where to search
                'showOnAdvancedSearchForm' => true,
                //list of options
                'options' => array(
                    'all' => 'Everywhere',
                    'content' => 'In page content',
                    'name' => 'In page name',
                ),
                //default value
                'default' => 'all'
            ),
            'searchType' => array(
                'showOnAdvancedSearchForm' => true,
                //list of options
                'options' => array(
                    //  OR means any of given words must be present in result
                    'OR' => 'OR (any word should be present)',
                    //  EXACT means the searcher would search for exact phrase
                    'EXACT' => 'EXACT (search for exact phrase)',
                    //  AND means all words must be present in result
                    'AND' => 'AND (all word should be present)',
                    //  NOT will exclude all words except for the first one
                    'NOT' => 'NOT (all words, except for the first one, must be absent in result)',
                ),
                'enableSearchOperators' => true,
                //default value
                'default' => 'OR'
            ),
            'urlLimiter' => array(
                //show dropdown list on advanced search form to select where to search
                'showOnAdvancedSearchForm' => true,
                //list of options
                'options' => array( //                    'all' => 'No filter',
//                    '/company/' => 'Company',
//                    '/blog/' => 'Blog',
                ),
                //default value
                'default' => 'all'
            ),
            //this string will always be added to th end of all search requests
            // should start with AND
            'staticString' => '',
            // enable Search Operators AND OR NOT
            //'enableSearchOperators' => true
        ),
        // personalisation of cms pages
        'personalisation' => array(
            'class' => 'common.modules.personalisation.PersonalisationModule',
            'rule' => 'personalisation.components.BasicPersonalisationRule',
            'cacheTime' => 30
        ),
        // settings in user admin area
        'settings' => array(
            'class' => 'common.modules.settings.SettingsModule',
            'fields' => array(
                'defaultLandingPage',
            ),
            'layoutForBackend' => '//layouts/gportal',
        ),
          //Comments module
        'comments' => array(
            'class' => 'common.modules.comments.CommentsModule',
            //salt which is used for every hash operation in this module
            'hashSalt' => 'h1ads29ds1a91hgj29jl451',
            'notificationsEmail' => 'portal.comments@gentics.com',
            // cache time in seconds
            'cacheTime' => 30
        ),
        //Like module
        'like' => array(
            //Module class location
            'class' => 'common.modules.like.LikeModule',
            /*  quantity of likes to be shown after like/unlike button   */
            'topLikesQty' => 3,
            /*  quantity of likes to be shown in overlay   */
            'lastLikesQty' => 2,
            /*  cache life time in seconds */
            'cacheTime' => 12 * 60 * 60,
        ),
        //tagcloud module
        'tagcloud' => array(
            //Component class
            'class' => 'common.modules.tagcloud.tagcloudModule',
            //  cache life time in seconds
            'cacheTime' => 60,
            //default CMS page with personalizedOverview widget
            'defaultOverviewPage' => '/Content.Node/testing/Overview.en.html',
            //CMS pages with personalizedOverview widget per language
            'overviewPages' => array(
                'en' => '/Content.Node/testing/Overview.en.html',
                'de' => '/Content.Node/testing/Overview.de.html',
            ),
            //String that will be used as tags separator
            'tagsSeparator' => ', ',
            //tagstyles. Array of styles for tags. Controls weights gradations and styles.
            // So if 3 gradations defined - tags would be separated into 3 categories
            //must be defined from most light(rare) to most heavy(frequent)
            'tagstyles' => array(
                'tagsize_1',    //ex.: 10px
                'tagsize_2',    //ex.: 14px
                'tagsize_3',    //ex.: 16px
            )
        ),                
        'social' => array(
            'class' => 'common.modules.social.SocialModule',
            //email used for mailsending
            'mailsendingEmail' => 'portal.link@gentics.com'
        ),
        /**
        'pdf' => array(
            'class' => 'common.modules.pdf.PdfModule',
        ),
        **/
        // NON CORE MODULES - only be used with special licenses
        'shoppingcart' => array(
            'class' => 'common.modules.shoppingcart.ShoppingCartModule',
            'usermail_template' => 'usermail_template',
            'adminemail_template' => 'adminemail_template',
            'cookie_domain' => '.gentics.com',
            'thankyoupage' => array(
                'de'=>'/Content.Node/service/Shopping_Cart_Thank_You.de.html',
                'en'=>'/Content.Node/service/Shopping_Cart_Thank_You.en.html',
            ),
	        'max_lifetime' => 50,
            'shipping_costs' => 100,
            'currency' => '&euro;',
            'notificationsEmail' => 'portal.shoppingcart@gentics.com',
            'captchaEnabled' => false
        ),
       'remember' => array(
            'class' => 'common.modules.remember.RememberModule',
            'facebookApplicationId' => '441157159266533',
            'signSalt' => 'sign-salt',
            'shareByMailEmail' => 'portal.remember@gentics.com',
            'shareByMailSubject' => 'Remember subject',
            'allowedURL' => '.gentics.com',
            'pdfname' => 'Remembered_Pages.pdf',
            'tmpFolder' => '/tmp/'
        ),
        'history' => array(
            'class' => 'common.modules.history.HistoryModule',
            'cacheTime' => 3600,
            'autoSave' => false,
        ),
        'piwik' => array(
           'class' => 'common.modules.piwik.PiwikModule', 
           'cacheTime' => 3600*24,
           'token' => 'b6c8329bcdfyxgrehdfsghfdgf9845',
           'piwikServerURL' => 'http://piwik.gentics.com',
           'sites' => 'all',
        ),
        'vote' => array(
            'class' => 'common.modules.vote.VoteModule',
            'debug' => false
        ),
         'friends' => array(
            'class' => 'common.modules.friends.FriendsModule',
            'notificationsEmail' => 'portal.friends@gentics.com'
        ),
        'fg' => array(
            'class' => 'common.modules.fg.FgModule',
            // editor client root path
            'clientBasePath' => 'http://cms.gentics.com/formgenerator',
            // editor client server local path
            'clientLocalPath' => '/Node/var/httpd/htdocs/formgenerator',
            'proxyPath' => '',
            'defaultLogin' => array(
                    'username' => 'dummyuser@gentics.com', 
                    'password' => 'dummy'
            ),
            'thankYouPage' => "/danke.html"
    	),
        'apalines' => array(
            'class' => 'common.modules.apalines.APALinesModule',
            'channel' =>
            array(
                'name' => 'sport', // add this channel as a field to the database so we can import in 1 database table many news from different "channels"
                'max_age_of_news' => 60*60,
                'max_count_of_news' => 30,
                'delivery_path' => 'apalines.sports',//there will be news1,news2..,
                'subfolders' => array ( 'news1', 'news2' )
            ),
             array(
                'name' => 'economy',
                'max_age_of_news' => 60*60,
                'max_count_of_news' => 30,
                'delivery_path' => 'apalines.economy',//there will be news1,news2..,
                'subfolders' => array ( 'news1', 'news2' )
             ),
        ),
    ),
    //The application components (indexed by their IDs).
    'components' => array(
        //Gentics Content Connector configuration
        'repositoryApi' => array(
            'class' => 'common.components.RepositoryApi',
            'url' => 'http://localhost:8080',
            //path to component that processes navigation requests
            'navigation' => '/ccr/nav',
            'binaryContent' => '/ccr/content',
            'contentRepositorySearch' => '/ccr/ccr',
            //path to component that processes search requests
            'search' => '/ccr/search',
            //path to component that processes active paths requests
            'activePath' => '/ccr/ap',
            //path to component that processes autosuggest requests
            'autosuggest' => '/ccr/autocomplete',
            'contentExternalHost' => '',
            //parameters which will be added to every request to gentics content connector
            //parameters which will be added to certain request to GCC
            'additionalRequestParameters' => array(
                'contentRepositorySearch' => array( //                    'filter' => 'object.node_id=="4"'
                ),
                'binaryContent' => array( //                    'filter' => 'object.node_id=="4"'
                ),
                'search' => array( //                    'filter' => 'node_id:4'
                )
            ),
            // Attributes, which will be added to every request as "&attribute=something"
            'additionalAttributes' => array(
//              'content',                            
            ),
            // Sorting-Rules, that can be added to spezific requests
            'additionalSortingRules' => array(
 //               '/ccr/nav' => 'name:asc'
            )
            
        ),
        'messages' => array(
            'class' => 'PhpMessageSource',
            //If true try to use dictionary files from custom section
            'customI18n' => true,
            'forceTranslation' => true
        ),
        //Component for Yii::app()->user {@link RWebUser}
        'user' => array(
            //Component class
            'class' => 'rights.components.RWebUser',
            // enable cookie-based authentication
            'allowAutoLogin' => true,
            //the URL for login
//            'loginUrl' => array('/user/login'),
        ),
        //Component for checking RBAC rights
        'authManager' => array(
            //Component class
            'class' => 'RDbAuthManager',
            //array list of role names that are assigned to all users implicitly.
            //These roles do not need to be explicitly assigned to any user.
            //When calling {@link checkAccess}, these roles will be checked first.
            //For performance reason, you should minimize the number of such roles.
            'defaultRoles' => array('Guest', 'Authenticated')
        ),
        //Components manages the URLs of Web applications.
        'urlManager' => array(
            //The URL format. Defaults to 'path'. Valid values include 'path' and 'get'.
            'urlFormat' => 'path',
            //whether to show entry script name in the constructed URL. Defaults to true
            'showScriptName' => false,
            //array the URL rules (pattern=>route).
            'rules' => array(
                'user/assignment/<action:\w+>' => 'user/rightsAssignment/<action>',
                '<path:Content\.Node\/.+\.(php|html)>' => 'contentSource/renderer/dynamic',
                '<path:Content\.Node\/.+\.(.+)>' => 'contentSource/renderer/static',
//                '<path:Content\.Node\/.+>' => 'contentSource/renderer/static',
//                '<path:GenticsImageStore\/.+>' => 'contentSource/renderer/static',
                //handle folder startpage
                '<path:Content\.Node><folder:\/.+>' => 'contentSource/renderer/startPage',
                '<controller:\w+>/<id:\d+>' => '<controller>/view',
                '<controller:\w+>/<action:\w+>/<id:\d+>' => '<controller>/<action>',
                '<controller:\w+>/<action:\w+>' => '<controller>/<action>',
                '<module:\w+>/<controller:\w+>/<action:\w+>' => '<module>/<controller>/<action>',
                '<controller:\w+>' => '<controller>/index',
            ),
        ),
        //AssetManager is a Web application component that manages private files (called assets) and makes them accessible by Web clients
        'assetManager' => array(
            // @var boolean whether to use symbolic link to publish asset files. Defaults to false, meaning asset files are copied to public folders.
//            'linkAssets' => true,
            'class' => 'common.components.AssetsManager'
        ),
        //ClientScript manages JavaScript and CSS stylesheets for views.
        //Can compress and combine CSS and JS files depends of settings
        'clientScript' => array(
            'class' => 'common.extensions.ExtendedClientScript.ExtendedClientScript',
            // this must be disabled
            'disableRegisterFiles' => true,
            //JS and CSS compression tool settings
            //Used for garbage collection. After that period (in days) clean files.
            'ttlDays' => 1,
            //combine css files to single file
            'combineCss' => false,
            //compress css files
            'compressCombinedCss' => false,
            //combine js files to single file
            'combineJs' => false,
            //compress js files
            'compressCombinedJs' => false,
            //javascript minificator class location
            'jsMinPath' => 'common.extensions.ExtendedClientScript.jsmin.*',
            //CSS minificator class location
            'cssMinPath' => 'common.extensions.ExtendedClientScript.cssmin.*',
            //domain for splitting js/css files across domains
            //'splitDomainName' => 'cdn.google.com'
        ),
        //Component manager of database connections
        'db' => array(
            //Db component class
            'class' => 'DbConnectionMan',
            //DB connection string
            'connectionString' => 'mysql:host=localhost;dbname=gportal',
            //whether to turn on prepare emulation. Defaults to false, meaning PDO will use the native prepare support if available.
            'emulatePrepare' => true,
            //the default prefix for table names. Defaults to null, meaning no table prefix.
            'tablePrefix' => 'gportal_',
            //DB username
            'username' => 'root',
            //DB Password
            'password' => '',
            'charset' => 'utf8',
            //whether the database connection should be automatically established the component is being initialized.
            'autoConnect' => false,
            //whether to enable profiling the SQL statements being executed. This should be mainly enabled and used during development
            //to find out the bottleneck of SQL executions.
            'enableProfiling' => true,
            //whether to log the values that are bound to a prepare SQL statement
            'enableParamLogging' => true,
            //number of seconds that table metadata can remain valid in cache. 86400, 0 - disabled
            'schemaCachingDuration' => 0,
            //Read write splitting function is swithable.You can specify this value to false to disable it.
            'enableSlave' => false,
            //slave connection config is same as CDbConnection
            'slaves' => array(),
            //slave connection config is same as CDbConnection
/**
            'slaves' => array(
                'slave1' => array(
                    'connectionString' => 'mysql:host=slave1;dbname=xxx',
                    'username' => 'root',
                    'password' => '********'
                ),
            ),
**/            
        ),
        //Cache settings
        'cache' => array(
            //Class for caching
            //CMemCache: uses PHP memcache extension.
            //CApcCache: uses PHP APC extension.
            //CXCache: uses PHP XCache extension.
            //CEAcceleratorCache: uses PHP EAccelerator extension.
            //CDbCache: uses a database table to store cached data. By default, it will create and use a SQLite3 database under the runtime directory.
            //You can explicitly specify a database for it to use by setting its connectionID property.
            //CZendDataCache: uses Zend Data Cache as the underlying caching medium.
            //CFileCache: uses files to store cached data. This is particular suitable to cache large chunk of data (such as pages).
            //CDummyCache: is a placeholder cache component.
            'class' => 'system.caching.CMemCache',
            //List of memcache server configurations. Each element is a CMemCacheServerConfiguration.
            //'servers' => array('localhost'),
            /**
            'servers' => array(
                'server1' => array('host' => '127.0.0.1', 'port' => 11211, 'weight' => 60),
            ),
            **/
        ),
        //Component for storing session.
        //It implements a session component using cache as storage medium.
        /*
        'session' => array(
            'class' => 'system.web.CCacheHttpSession',
            //The session cookie parameters.
            'cookieParams' => array(
                //If true cookie will only be sent over secure connections.
//                'secure' => true,
                //Cookie domain, for example 'www.php.net'. To make cookies visible on all subdomains then
                //the domain must be prefixed with a dot like '.php.net'.
//                'domain' => 'portal.com'
                //Lifetime of the session cookie, defined in seconds.
//                'lifetime' => 0,
                //Path on the domain where the cookie will work. Use a single slash ('/') for all paths on the domain.
//                'path' => '/'
                //If set to true then PHP will attempt to send the httponly flag when setting the session cookie.
                'httponly' => false

            ),
        ),**/
        //CHttpRequest component settings
        'request' => array(
            //whether cookies should be validated to ensure they are not tampered. Defaults to false
            'enableCookieValidation' => true, /*http://www.yiiframework.com/doc/guide/1.1/en/topics.security#cookie-attack-prevention*/
            //whether to enable CSRF (Cross-Site Request Forgery) validation. Defaults to false.
            'enableCsrfValidation' => true,
        ),

        //logger settings
        'log' => array(
            //Component class
            'class' => 'CLogRouter',
            'routes' => array(
                //php error log
                'errorLog' => array(
                    'class' => 'CFileLogRoute',
                    'categories' => 'php, exception.Exception*, exception.CDbException*',
                    'logPath' => Yii::getPathOfAlias('site.custom.runtime'),
                ), //php,
                //email error logger
                'emailLog' => array(
                    'class' => 'CEmailLogRoute',
                    'subject' => 'Gentics Content.Node Application Error',
                    'emails' => array(),
                    'categories' => 'php, exception.Exception*, exception.CDbException*',
                ),
                'notificationLog' => array(
                    'class' => 'CFileLogRoute',
                    'logPath' => Yii::getPathOfAlias('site.custom.runtime'),
                    'logFile' => 'FileLogNotificator.log',
                    'categories' => 'FileLogNotificator'
                ),
                'mailNotificationLog' => array(
                    'class' => 'CFileLogRoute',
                    'logPath' => Yii::getPathOfAlias('site.custom.runtime'),
                    'logFile' => 'MailNotificationLog.log',
                    'categories' => 'MailNotificator'
                ),
                //profiler, showed execution time
                'profilerLog' => array(
                    'class'=>'CProfileLogRoute',
                    'levels'=>'profile',
                    'enabled'=>YII_DEBUG && (strripos($_SERVER['REQUEST_URI'], ".html") || strripos($_SERVER['REQUEST_URI'], ".php")),
                ),
                //profile '_GET', '_POST', '_FILES', '_SESSION', '_COOKIES' vars
                'web' => array(
                    'class' => 'CWebLogRoute',
                    'enabled'=>YII_DEBUG && (strripos($_SERVER['REQUEST_URI'], ".html") || strripos($_SERVER['REQUEST_URI'], ".php")),
                    'levels' => 'trace',
                    'filter' => array(
                        'class' => 'CLogFilter',
                        'logVars' => array('_GET', '_POST', '_FILES', '_SESSION', '_COOKIES'),
                    ),
                ),
            ),
        ),

        //Notification manager component
        'notificationManager' => array(
            //Component class
            'class' => 'common.components.notification.NotificationManager',
            //cache time for user model
            'cacheTime' => 10,
            //notificators for handling notificators
            'notificators' => array(
                'mail' => array(
                    //notificator class
                    'class' => 'common.components.notification.MailNotificator',
                    //PhpMailer extension options
                    'phpMailer' => array(
                        'CharSet' => 'UTF-8',
                    )
                ),
                'file' => array(
                    //notificator class
                    'class' => 'common.components.notification.FileLogNotificator',
                )
            )
        ),
        //TPA extension settings
        'eauth' => array(
            //Component class
            'class' => 'common.extensions.eauth.EAuth',
            // Use the popup window instead of redirecting.
            'popup' => true,
            //currenly using services for authentication /var/www/gportalapp
            'services' => array(
             /**
                'standard' => array(
                    'title' => 'With username/password'
                ),
                'google' => array(
                    'class' => 'site.common.modules.user.services.GoogleService',
                    'title' => 'Google Open ID'
                ),
                'facebook' => array(
                    // application register at: https://developers.facebook.com/apps/
                    'title' => 'Facebook Auth',
                    'class' => 'site.common.modules.user.services.FacebookService',
                    'client_id' => '410189012355646',
                    'client_secret' => '967c3665417122760e33ebfeec6c1e3d',
                    'scope' => 'email'
                ),
            **/
            )
        ),        
        //extension needed for TPA
        'loid' => array(
            //Component class
            'class' => 'common.extensions.lightopenid.loid',
        ),
        //
        'errorHandler' => array(
            'class' => 'ErrorHandler',
            'errorAction' => 'site/error',
            'errorPages' => array(
                'e400' => array(
                    'en' => '/site/error400',
                ),
                'e403' => array(
                    'en' => '/site/error403',
                ),
                'e404' => array(
                    'en' => '/site/error404',
                ),
                //for system exceptions
                'e500' => array(
                    'en' => '/site/error500',
                ),
            )
        )
    ),
    //Additional params
    'params' => array(
        //If true try to use view files from custom section
        'customViews' => true,
        /**
        //client information, in future will be moved from config file into DB
        'client' => array(
            'username' => 'guest',
        ),
        'emailForAllMails' => array('test@example.com'),
        'ldap' => array(
            'host' => 'mail.gentics.com',
            'ou' => 'Users',
            'dc' => array('gentics', 'com')
        )
        **/
    ),
);
