#!/bin/bash
#
# Gentics Portal.Node PHP
# Author & Copyright (c) by Gentics Software GmbH
# sales@gentics.com
# http://www.gentics.com
# Licenses can be found in the LICENSE.txt file in the root-folder of this installation
# You must not use this software without a valid license agreement.
#

## installation for debian Linux

function handleError() {
  if [ "$1" != "0" ]; then
     echo -e "\n\nERROR: $2"
     echo -e "Aborting with errorcode $1 \n\n"
     exit 10
  fi
}

function phpVersion(){
    rawVersion=`php -r \@phpinfo\(\)\; | grep -m 1 'PHP Version'`       
    [[ $rawVersion =~ PHP\ Version\ =\>\ ([0-9]\.[0-9]\.[0-9]) ]]    
    echo ${BASH_REMATCH[1]}
}

function binExists(){
    command -v $1 > /dev/null
    echo $?
}

# testing if php is installed
which php > /dev/null
handleError $? "Could not find PHP within PATH. Please install PHP according to described procedure in installation."

if [[ $(phpVersion) < "5.3.0" ]]; then
    echo "Your PHP version is $(phpVersion). You need at least 5.3.0" 
    exit
fi     

# memcached checking and installation
if [ $(binExists memcached) != '0' ]; then
    read -p "memcached does not exist. Shall we try to install it? (y/n)" answ
    if [ $answ = 'y' ]; then
        if [[ $(binExists 'apt-get') == "0" ]]; then
            apt-get install memcached php5-memcached php5-memcache
            /etc/init.d/memcached restart 
        elif [[ $(binExists 'yum') == "0" ]]; then
            yum install memcached php-pecl-memcached php-pecl-memcache
            service memcached start
            chkconfig memcached on
        elif [[ $(binExists 'up2date') == "0" ]]; then
            up2date memcached php-pecl-memcached php-pecl-memcache
            service memcached start
            chkconfig memcached on
        else
            echo 'Error! No package manager found! Please install memcached manually.'        
        fi    
    else
        echo "Please install $package manually"    
    fi
else
    echo "Package $package installed!"
fi

# make folders and files writeable
chmod go+w ../custom/config/*
chmod go+w ../common/runtime
chmod go+w ../custom/runtime
chmod go+w ../tests/runtime
chmod go+w ../frontend/runtime
chmod go+w ../frontend/www/assets
chmod a+x ../common/yiic

# copy custom config
cp -n ../custom/config/client_main.php.dist ../custom/config/client_main.php
cp -n ../custom/config/client_console.php.dist ../custom/config/client_console.php

# run installation
#cd ./scripts
php install.php
#cd ..

# copy the client_config to production
DATE=`date +%Y%m%d%H%M%S`
cp ../custom/config/client_main.php ../custom/config/client_main_$DATE.php
cp ../custom/runtime/client_main.php ../custom/config/client_main.php

# run migrations
cd ../common
./yiic migrate --interactive=0
cd ../scripts

# deleting the installscript
#while true; do
#    read -p "For security reasons we should delete the installation script. Do you want to delete it now? (y/n)" yn
#    case $yn in
#        [Yy]* ) rm ./install.sh; rm ./install.bat; break;;
#        [Nn]* ) exit;;
#        * ) echo "Please answer with yes or no. (y/n)";;
#    esac
#done

