#!/bin/bash
#
# Gentics Portal.Node PHP
# Author & Copyright (c) by Gentics Software GmbH
# sales@gentics.com
# http://www.gentics.com
# Licenses can be found in the LICENSE.txt file in the root-folder of this installation
# You must not use this software without a valid license agreement.
#

DATE=`date +%Y%m%d%H%M%S`

function prompt(){
    while true; do
        read -p "$1 (y|n)" yn
        case $yn in
            [Yy]* ) echo 'y'; break;;
            [Nn]* ) echo 'n'; break;;
            * ) echo "Please answer with yes or no (y|n)!";;
        esac
    done
}

function ask(){
    read -p "$1" answ
    echo $answ
}

##downloadUrl=''
#if download new version
##answ=$(prompt 'Download new version?')
##updateFolder=''
##if [ $answ == 'y' ]; then
##    #save it locally and unzip
##    echo 'downloading...'
##    updateFolder='location'
##else    
##    #else update from current folder    
   cd ..
   updateFolder=$(dirname $(readlink -f $0))
##fi

#ask where the current portal is
while true; do
    applicationFolder=$(ask "Specify the path to web application directory of GPN PHP (no trailing slash):")
    if [[ -e "$applicationFolder/frontend/www/index.php" ]];then    
        break;
    else
        echo 'Folder is not correct. Try once again please'
    fi
done

#check if there is client_console.php

if [ ! -f "$applicationFolder/custom/config/client_console.php" ];then
    echo '/custom/config/client_console.php does not exist. Please create it by copying the client_console.php.dist and specify DB connection parameters in it first'
    exit
fi

#ask if script should make a backup
answ=$(prompt "Shall we make a backup of your current installation of GPN PHP?")
if [[ $answ = "y" ]]; then
    while true; do
        backupFolder=$(ask "Define backup folder (no trailing slash):")

        if [[ -d "$backupFolder" ]];then    
            break;
        else
            echo 'Folder is not correct. Try once again please.'
        fi
    done    
    #make backup
    rm -rf "$backupFolder/portal_backup_$DATE"
    mkdir "$backupFolder/portal_backup_$DATE"
    cp -r $applicationFolder/* "$backupFolder/portal_backup_$DATE"
    #include mysql dumper
    # add backup-folder as properties
    cd scripts/
    source mysqlBackup.sh
    cd ..

    echo You can find backup by path: "$backupFolder/portal_backup_$DATE"
fi

#start update process
answ=$(prompt "Can we start with the update?")
if [[ $answ = "y" ]]; then
    #backup www
    rm -rf /tmp/gpn_www_orig
    mkdir /tmp/gpn_www_orig
    cp -a $applicationFolder/frontend/www /tmp/gpn_www_orig
    #place new files
    cd scripts/
    scriptDir=$(dirname $(readlink -f $0))
    cd $applicationFolder
    rm -rf `ls $updateFolder | grep -Ev '^custom$'`
    cp -r `find $updateFolder -maxdepth 1 | grep -Ev "$updateFolder/custom|(^$updateFolder$)"` .
    cd $scriptDir
    #restore www
    rm -rf $applicationFolder/frontend/www
    cp -a /tmp/gpn_www_orig/www/ $applicationFolder/frontend/
else
    exit
fi

mkdir -p $applicationFolder/common/runtime
mkdir -p $applicationFolder/custom/runtime
mkdir -p $applicationFolder/tests/runtime
mkdir -p $applicationFolder/frontend/runtime
mkdir -p $applicationFolder/frontend/www/assets

#set folders permissions
# make folders and files writeable
chmod go+w $applicationFolder/custom/config/*
chmod go+w $applicationFolder/common/runtime
chmod go+w $applicationFolder/custom/runtime
chmod go+w $applicationFolder/tests/runtime
chmod go+w $applicationFolder/frontend/runtime
chmod go+w $applicationFolder/frontend/www/assets
chmod a+x $applicationFolder/common/yiic

# run migrations
$applicationFolder/common/yiic migrate --interactive=0

#add new config params
#TODO

#ask if remove this script
answ=$(ask "For security reasons we should delete the update script. Do you want to delete it now? (y|n)")
if [[ $answ = 'y' ]]; then
    rm $applicationFolder/scripts/$(basename $0)
    rm $applicationFolder/scripts/update.bat
    rm $applicationFolder/scripts/install.bat
    rm $applicationFolder/scripts/install.sh
fi

#success message
echo "Update process finished!"

